# Connection 예제

이것은 Ezi-SERVOII Plus-E 제품을 연결하고, 제품의 정보를 확인하는 예제입니다.

## 1. 연결

``` c++
bool Connect(int nCommType, int nBdID)
{
	BYTE byIP[4] = { 192, 168, 0, 2 }; // IP : 192.168.0.2
	bool bSuccess = true;

	// Connection
	switch (nCommType)
	{
	case TCP:
		// TCP Connection
		if (FAS_ConnectTCP(byIP[0], byIP[1], byIP[2], byIP[3], nBdID) == FALSE)
		{
			printf("TCP Connection Fail! \n");
			bSuccess = false;
		}
		break;

	case UDP:
		// UDP Connection
		if (FAS_Connect(byIP[0], byIP[1], byIP[2], byIP[3], nBdID) == FALSE)
		{
			printf("UDP Connection Fail! \n");
			bSuccess = false;
		}
		break;

	default:
		printf("Wrong communication type. \n");
		bSuccess = false;

		break;
	}

	if (bSuccess)
		printf("Connected successfully. \n");

	return bSuccess;
}
```
FAS_Connect는 UDP 연결을, FAS_ConnectTCP는 TCP 연결을 하는 함수입니다.

함수가 TRUE를 리턴하면 연결이 성공한 것입니다.

## 2. 제품 정보 확인
``` c++ 
bool CheckDriveInfo(int nBdID)
{
	BYTE byType = 0;
	char IpBuff[256] = "";
	int nBuffSize = 256;
	int nRtn;

	// Read Drive's information
	nRtn = FAS_GetSlaveInfo(nBdID, &byType, IpBuff, nBuffSize);
	if (nRtn != FMM_OK)
	{
		printf("Function(FAS_GetSlaveInfo) was failed.\n");
		return false;
	}

	printf("Board ID %d : TYPE= %d, Version= %s\n", nBdID, byType, IpBuff);

	return true;
}
```
연결 성공 후 제품의 정보를 확인하는 함수(FAS_GetSlaveInfo)를 사용하였습니다.
이 함수는 연결에 필요한 함수가 아닙니다. 연결 후 임의의 함수를 호출한 것입니다.

## 3. 연결 종료
``` c++
// Connection Close
FAS_Close(iBdID);
```
FAS_Close()를 통해 연결을 해제할 수 있습니다.
