# Parameter 설정 예제

## 1. Parameter 값 확인

``` c++
int lParamVal = 0;
// Check The Axis Start Speed Parameter Status
nRtn = FAS_GetParameter(nBdID, SERVO2_AXISSTARTSPEED, &lParamVal);
if (nRtn != FMM_OK)
{
	printf("Function(FAS_GetParameter) was failed.\n");
	return false;
}
else
{
	printf("Load Parameter[Before] : Start Speed = %d[pps] \n", lParamVal);
}
```

FAS_GetParameter 함수를 사용하여 현재 설정된 파라미터의 값을 확인할 수 있습니다.

### 1.1 파라미터 번호

SERVO2_AXISSTARTSPEED는 파라미터 번호입니다. 이것은 MOTION_SERVO2_DEFINE.h 파일에 정의되어 있습니다.

설정하고자 하는 파라미터의 번호는 해당하는 모델의 header 파일(Ezi-SERVOII Plus-E의 경우 MOTION_SERVO2_DEFINE.h)에서 확인하실 수 있습니다.
혹은, Ezi-MOTION Plus-E 프로그램의 Parameter List 화면에 표시되는 번호를 참고하시기 바랍니다.

## 2. Parameter 값 설정

``` c++
int nChangeValue = 100;
// Change the (Axis Start Speed Parameter) value to (nChangeValue) value.
nRtn = FAS_SetParameter(nBdID, SERVO2_AXISSTARTSPEED, nChangeValue);
if (nRtn != FMM_OK)
{
	printf("Function(FAS_SetParameter) was failed.\n");
	return false;
}
else
{
	printf("Set Parameter: Start Speed = %d[pps]\n", nChangeValue);
}
```

FAS_SetParameter 함수를 사용하여 파라미터의 값을 변경할 수 있습니다.

파라미터의 값은 설정하는 즉시 적용됩니다.

### 2.1 리턴값

FAS_SetParameter 함수의 리턴 값인 nRtn에는 함수의 성공 혹은 실패(그리고 실패의 원인)를 알려줍니다.

함수가 아무런 문제 없이 정상적으로 수행되었다면 FMM_OK를 리턴합니다. 

FMM_OK 이외의 값을 받았다면, 함수가 정상적으로 실행되지 못하였음을 가리킵니다.
FMC_TIMEOUT_ERROR는 제어기로 부터 아무런 응답을 받지 못하였음을 표시합니다. 제품의 전원이 꺼져 있지 않은지, Ethernet 케이블의 연결에 문제는 없는지 확인하시기 바랍니다.
FMP_DATAERROR는 설정하려는 값이 해당 파라미터의 범위를 벗어났음을 표시합니다. 해당 파라미터의 범위를 다시 확인하시기 바랍니다.

기타 여러 리턴값이 존재합니다. ReturnCodes_Define.h 파일과 제품의 매뉴얼을 참조하시기 바랍니다.
