﻿#include <iostream>
#include <unistd.h>
#include "../Include/FAS_EziMOTIONPlusE.h"

using namespace PE;

#define TCP 0
#define UDP 1

#define INPUTPIN 12

bool Connect(int nCommType, int nBdID);
bool SetInputPin(int nBdID);
bool CheckInputSignal(int nBdID);
bool WaitSeconds(int nSecond);

int main()
{
	int nBdID = 0;

	// Device Connect
	if (Connect(TCP, nBdID) == false)
	{
		getchar();
		exit(1);
	}

	// Set Input pins 
	if (SetInputPin(nBdID) == false)
	{
		getchar();
		exit(1);
	}

	// Check Input Pin Signal
	if (CheckInputSignal(nBdID) == false)
	{
		getchar();
		exit(1);
	}

	// Connection Close
	FAS_Close(nBdID);

	getchar();
}

bool Connect(int nCommType, int nBdID)
{
	unsigned char byIP[4] = { 192, 168, 0, 2 }; // IP : 192.168.0.2
	bool bSuccess = true;

	// Connection
	switch (nCommType)
	{
	case TCP:
		// TCP Connection
		if (FAS_ConnectTCP(byIP[0], byIP[1], byIP[2], byIP[3], nBdID) == 0)
		{
			printf("TCP Connection Fail! \n");
			bSuccess = false;
		}
		break;

	case UDP:
		// UDP Connection
		if (FAS_Connect(byIP[0], byIP[1], byIP[2], byIP[3], nBdID) == 0)
		{
			printf("UDP Connection Fail! \n");
			bSuccess = false;
		}
		break;

	default:
		printf("Wrong communication type. \n");
		bSuccess = false;

		break;
	}

	if (bSuccess)
		printf("Connected successfully. \n");

	return bSuccess;
}

bool SetInputPin(int nBdID)
{
	unsigned char byPinNo = 0;
	unsigned int dwLogicMask = 0;
	unsigned char byLevel = 0;

	unsigned int dwInputMask;

	printf("----------------------------------------------------------------------------- \n");

	// Set Input pin Value.
	byPinNo = 3;
	byLevel = LEVEL_LOW_ACTIVE;
	dwInputMask = SERVO2_IN_BITMASK_USERIN0;

	if (FAS_SetIOAssignMap(nBdID, byPinNo, dwInputMask, byLevel) != FMM_OK)
	{
		printf("Function(FAS_SetIOAssignMap) was failed.\n");
		return false;
	}
	else
	{
		printf("SERVO2_IN_BITMASK_USERIN0 (Pin%d) : [%s]\n", byPinNo, (byLevel == LEVEL_LOW_ACTIVE) ? "Low Active" : "High Active");
	}

	printf("----------------------------------------------------------------------------- \n");

	// Show Input pins status
	for (int i = 0; i < INPUTPIN; i++)
	{
		if (FAS_GetIOAssignMap(nBdID, i, &dwLogicMask, &byLevel) != FMM_OK)
		{
			printf("Function(FAS_SetIOAssignMap) was failed.\n");
			return false;
		}

		if (dwLogicMask != IN_LOGIC_NONE)
			printf("Input PIN[%d] : Logic Mask 0x%08x (%s) \n", i, dwLogicMask, ((byLevel == LEVEL_LOW_ACTIVE) ? "Low Active" : "High Active"));
		else
			printf("Input Pin[%d] : Not Assigned \n", i);
	}

	return true;
}

bool CheckInputSignal(int nBdID)
{
	unsigned int dwInput = 0;
	unsigned int dwInputMask = SERVO2_IN_BITMASK_USERIN0;

	printf("----------------------------------------------------------------------------- \n");

	// When the value SERVO2_IN_BITMASK_USERIN0 is entered with the set PinNo, an input confirmation message is displyed.
	// Monitoring input signal for 60 seconds
	do
	{
		if (FAS_GetIOInput(nBdID, &dwInput) == FMM_OK)
		{
			if (dwInput & dwInputMask)
			{
				printf("INPUT PIN DETECTED.\n");
			}
		}
		else
			return false;
	}
	while (WaitSeconds(60));

	printf("finish WaitSecond! \n");
	return true;
}

bool WaitSeconds(int nSecond)
{
	usleep(100*1000);

	static int nCnt = 0;
	if (nCnt++ < nSecond * 10)
		return true;
	else
		return false;
}
