# InputPinControlExam 예제

## 1. 예제 프로그램 시나리오 설명

해당 예제프로그램의 시나리오는 아래와 같습니다.

1. 장치 연결.
2. Input Pin 과 Bit Mask 의 연결 설정 및 설정값 재 확인.
3. 일정 시간(1분) 동안 입력핀 신호 감시.
4. 연결 해제.

## 2. 입력 PIN 설정


``` c++
// Set Input pin Value.
BYTE byPinNo = 3;
BYTE byLevel = LEVEL_LOW_ACTIVE;
DWORD dwInputMask = SERVO2_IN_BITMASK_PJOG;

if (FAS_SetIOAssignMap(nBdID, byPinNo, dwInputMask, byLevel) != FMM_OK)
{
	printf("Function(FAS_SetIOAssignMap) was failed.\n");
	return false;
}
```

### ※ 함수 구조

> FAS_SetIOAssignMap(int nBdID, BYTE iIOPinNo, DWORD dwIOLogicMask, BYTE bLevel)
> - iBdID : FAS_Connect 함수에서 설정한 Board ID 번호.
> - iIOPinNo : 읽어올 I/O Pin 번호.
> - dwIOLogicMask : 해당 핀에 할당할 Logic Mask 값.
> - bLevel : 해당 핀에 설정할 Active Level 값.


위 소스코드는 FAS_SetIOAssignMap() 함수를 사용하여 3번 핀에 Logic Mask(SERVO2_IN_BITMASK_PJOG) 및 동작 신호 Level 값을 설정합니다.
그에 따라 3번 핀으로 신호가 입력된다면 모터는 Positive JOG Move 동작을 실시하게 됩니다.

위와같이 Logic Mask 신호는 [Origin / Limit- / Limit+ / PT Start 등..]모터의 다양한 동작을 위해 정의된 Bit Mask 값이 사용되며, 모델의 header 파일(Ezi-SERVOII Plus-E의 경우 MOTION_EziSERVO2_DEFINE.h)에서 확인하실 수 있습니다.

따라서 FAS_SetIOAssignMap() 함수는 입출력핀에 Logic Mask 및 동작 신호 Level 값의 매칭을 통하여 해당 신호의 의미를 부여하게 되며, 의미가 부여된 핀에 입출력 신호를 통하여 사용자가 원하는 모터 동작을 진행할 수 있습니다.

더하여, FAS_SetIOAssignMap() 함수 사용하시 해당 핀에 매칭되는 Logic Mask값은 RAM에 저장되게 됩니다.

## 3. 입력 PIN 설정값 확인

``` c++
DWORD dwLogicMask = 0;

// Show Input pins status
for (int i = 0; i < INPUTPIN; i++)
{
	if (FAS_GetIOAssignMap(nBdID, i, &dwLogicMask, &byLevel) != FMM_OK)
	{
		printf("Function(FAS_SetIOAssignMap) was failed.\n");
		return false;
	}

	if (dwLogicMask != IN_LOGIC_NONE)
		printf("Input PIN[%d] : Logic Mask 0x%08x (%s) \n", i, dwLogicMask, ((byLevel == LEVEL_LOW_ACTIVE) ? "Low Active" : "High Active"));
	else
		printf("Input Pin[%d] : Not Assigned \n", i);
}
```

### ※ 함수 구조
> FAS_GetIOAssignMap(int iBdID, BYTE iIOPinNo, DWORD* dwIOLogicMask, BYTE* bLevel)
>
> - iBdID : FAS_Connect 함수에서 설정한 Board ID 번호.
> - iIOPinNo : 읽어올 I/O Pin 번호.
> - dwIOLogicMask : 해당 Pin에 할당된 Logic Mask값이 저장될 포인터 변수.
> - bLevel : 해당 핀의 Active Level 값이 저장될 포인터 변수.


위 소스코드는 FAS_SetIOAssignMap() 함수를 통하여 설정한 각 핀에 대한 Logic Mask (Bit Mask) 및 Level 값을 FAS_GetIOAssignMap() 함수를 통하여 읽어들입니다.

읽어들인 각 핀의 Logic Mask 및 Level 값을 화면에 출력합니다.

## 4. 입력 신호 확인

``` c++
DWORD dwInput = 0;
DWORD dwInputMask = SERVO2_IN_BITMASK_USERIN0;

printf("----------------------------------------------------------------------------- \n");

// When the value SERVO2_IN_BITMASK_USERIN0 is entered with the set PinNo, an input confirmation message is displyed.
// Monitoring input signal for 60 seconds
do
{
	if (FAS_GetIOInput(nBdID, &dwInput) == FMM_OK)
	{
		if (dwInput & dwInputMask)
		{
			printf("INPUT PIN DETECTED.\n");
		}
	}
	else
		return false;
} while (WaitSeconds(60));
```

위 소스코드는 1분동안 FAS_GetIOInput() 함수를 사용하여 핀 전체의 상태값을 확인합니다.

특히 Positive Jog에 대한 Logic Mask(Bit Mask)값을 비교하여 해당 비트의 입력이 확인된다면 "INPUT PIN DETECTED" 문구를 화면해 현시합니다.

### ※ 함수 상세 설명
> FAS_GetIOInput(int iBdID, DWORD* dwIOInput)
>
> - iBdID : FAS_Connect 함수에서 설정한 Board ID 번호.
> - dwIOInput : Input 값이 저장될 포인터 변수.

## 5. 참고

1. 장치 연결 및 해제에 대한 기능 설명은 ConnectionExam 프로젝트 문서를 참고하시기 바랍니다.
