﻿#include <iostream>
#include <unistd.h>
#include "../Include/FAS_EziMOTIONPlusE.h"

using namespace PE;

#define TCP 0
#define UDP 1

#define INPUTPIN    12
#define OUTPUTPIN   10

bool Connect(int nCommType, int nBdID);
bool SetOutputPin(int nBdID);
bool ControlOutputSignal(int nBdID);
bool WaitSeconds(int nSecond);

int main()
{
	int nBdID = 0;

	// Device Connect
	if (Connect(TCP, nBdID) == false)
	{
		getchar();
		exit(1);
	}

	// Set Output pin 
	if (SetOutputPin(nBdID) == false)
	{
		getchar();
		exit(1);
	}

	// Control output pin signal
	if (ControlOutputSignal(nBdID) == false)
	{
		getchar();
		exit(1);
	}

	// Connection Close
	FAS_Close(nBdID);

	getchar();
}

bool Connect(int nCommType, int nBdID)
{
	unsigned char byIP[4] = { 192, 168, 0, 2 }; // IP : 192.168.0.2
	bool bSuccess = true;

	// Connection
	switch (nCommType)
	{
	case TCP:
		// TCP Connection
		if (FAS_ConnectTCP(byIP[0], byIP[1], byIP[2], byIP[3], nBdID) == 0)
		{
			printf("TCP Connection Fail! \n");
			bSuccess = false;
		}
		break;

	case UDP:
		// UDP Connection
		if (FAS_Connect(byIP[0], byIP[1], byIP[2], byIP[3], nBdID) == 0)
		{
			printf("UDP Connection Fail! \n");
			bSuccess = false;
		}
		break;

	default:
		printf("Wrong communication type. \n");
		bSuccess = false;

		break;
	}

	if (bSuccess)
		printf("Connected successfully. \n");

	return bSuccess;
}

bool SetOutputPin(int nBdID)
{
	unsigned char byPinNo = 0;
	unsigned char byLevel = 0;

	unsigned int dwLogicMask = 0;
	unsigned int dwOutputMask;

	printf("----------------------------------------------------------------------------- \n");
	// Check OutputPin Status
	for (int i = 0; i < OUTPUTPIN; i++)
	{
		if (FAS_GetIOAssignMap(nBdID, INPUTPIN + i, &dwLogicMask, &byLevel) != FMM_OK)
		{
			printf("Function(FAS_GetIOAssignMap) was failed.\n");
			return false;
		}

		if (dwLogicMask != IN_LOGIC_NONE)
			printf("Output Pin[%d] : Logic Mask 0x%08x (%s) \n", i, dwLogicMask, ((byLevel == LEVEL_LOW_ACTIVE) ? "Low Active" : "High Active"));
		else
			printf("Output Pin[%d] : Not Assigned \n", i);
	}

	printf("----------------------------------------------------------------------------- \n");

	// Set Output pin Value.
	byPinNo = 3;
	byLevel = LEVEL_HIGH_ACTIVE;
	dwOutputMask = SERVO2_OUT_BITMASK_USEROUT0;

	if (FAS_SetIOAssignMap(nBdID, INPUTPIN + byPinNo, dwOutputMask, byLevel) != FMM_OK)
	{
		printf("Function(FAS_SetIOAssignMap) was failed.\n");
		return false;
	}

	// Show Output pins status
	for (int i = 0; i < OUTPUTPIN; i++)
	{
		if (FAS_GetIOAssignMap(nBdID, INPUTPIN + i, &dwLogicMask, &byLevel) != FMM_OK)
		{
			printf("Function(FAS_GetIOAssignMap) was failed.\n");
			return false;
		}

		if (dwLogicMask != IN_LOGIC_NONE)
			printf("Output Pin[%d] : Logic Mask 0x%08x (%s) \n", i, dwLogicMask, (byLevel == LEVEL_LOW_ACTIVE) ? "Low Active" : "High Active");
		else
			printf("Output Pin[%d] : Not Assigned \n", i);
	}

	return true;
}

bool ControlOutputSignal(int nBdID)
{
	unsigned int dwOutputMask = SERVO2_OUT_BITMASK_USEROUT0;

	printf("----------------------------------------------------------------------------- \n");

	// Control output signal on and off for 60 seconds
	do
	{
		usleep(1000);
		// USEROUT0: ON
		if (FAS_SetIOOutput(nBdID, dwOutputMask, 0) != FMM_OK)
		{
			printf("Function(FAS_SetIOOutput) was failed.\n");
			return false;
		}

		usleep(1000);
		// USEROUT0: OFF
		if (FAS_SetIOOutput(nBdID, 0, dwOutputMask) != FMM_OK)
		{
			printf("Function(FAS_SetIOOutput) was failed.\n");
			return false;
		}
	}
	while (WaitSeconds(60));

	printf("finish WaitSecond! \n");
	return true;
}

bool WaitSeconds(int nSecond)
{
	usleep(100 * 1000);

	static int nCnt = 0;
	if (nCnt++ < nSecond * 10)
		return true;
	else
		return false;
}
