# OutputPinControlExam 예제

## 1. PIN 설정값 확인

``` c++
BYTE byLevel = 0;
DWORD dwLogicMask = 0;

// Check OutputPin Status
for (int i = 0; i < OUTPUTPIN; i++)
{
	if (FAS_GetIOAssignMap(nBdID, INPUTPIN + i, &dwLogicMask, &byLevel) != FMM_OK)
	{
		printf("Function(FAS_GetIOAssignMap) was failed.\n");
		return false;
	}

	if (dwLogicMask != IN_LOGIC_NONE)
		printf("Output Pin[%d] : Logic Mask 0x%08x (%s) \n", i, dwLogicMask, ((byLevel == LEVEL_LOW_ACTIVE) ? "Low Active" : "High Active"));
	else
		printf("Output Pin[%d] : Not Assigned \n", i);
}
```

FAS_GetIOAssignMap() 함수를 사용하여 드라이브의 I/O 커넥터(CN1)의 특정 핀에 대한 기능 및 동작 Level 상태값을 확인 할 수 있다.

### 1.1 Logic값 확인

특정 핀의 Logic값 유효성을 확인할 비교 데이터는 헤더파일(MOTION_DEFINE.h)에 정의되어 있습니다.

## 2.출력 PIN 제어

``` c++
// Set Output pin Value.
BYTE byPinNo = 0;
BYTE byLevel = 0;
DWORD dwOutputMask;

byPinNo = 3;
byLevel = LEVEL_HIGH_ACTIVE;
dwOutputMask = SERVO2_OUT_BITMASK_USEROUT0;

if (FAS_SetIOAssignMap(nBdID, INPUTPIN + byPinNo, dwOutputMask, byLevel) != FMM_OK)
{
	printf("Function(FAS_SetIOAssignMap) was failed.\n");
	return false;
}
```

FAS_SetIOAssignMap()함수를 사용하여 CN1의 특정핀에 대한 Logic값 및 동작 Level 값을 설정 할 수 있습니다.

### 2.1 BIT MASK값 확인

출력 PIN에 매칭될 BIT MASK값은 헤더파일(MOTION_EziSERVO2_DEFINE.h)에서 확인하실 수 있습니다.

## 3.출력 PIN 제어

``` c++
DWORD dwOutputMask = SERVO2_OUT_BITMASK_USEROUT0;

// Control output signal on and off for 60 seconds
do
{
	Sleep(1000);
	// USEROUT0: ON
	if (FAS_SetIOOutput(nBdID, dwOutputMask, 0) != FMM_OK)
	{
		printf("Function(FAS_SetIOOutput) was failed.\n");
		return false;
	}

	Sleep(1000);
	// USEROUT0: OFF
	if (FAS_SetIOOutput(nBdID, 0, dwOutputMask) != FMM_OK)
	{
		printf("Function(FAS_SetIOOutput) was failed.\n");
		return false;
	}
} while (WaitSeconds(60));
```

FAS_SetIOOutput() 함수를 사용하여 특정 핀의 출력 상태값을 제어(Set & Clear)할 수 있습니다.

## 4. 예제 프로그램 시나리오 설명

해당 예제프로그램의 시나리오는 아래와 같습니다.

1. 장치 연결.
2. 출력PIN 설정.
3. 출력PIN 설정 확인.
4. 일정 시간(1분) 동안 출력PIN 제어(ON / OFF).
5. 연결 해제.

## 5. 기타

1. 장치 연결 및 해제에 관한 기능 설명은 ConnectionExam 프로젝트 문서를 참고하시기 바랍니다.
