﻿#include <iostream>
#include <unistd.h>
#include "../Include/FAS_EziMOTIONPlusE.h"

using namespace PE;

#define TCP 0
#define UDP 1

#define CW  1
#define CCW 0

bool Connect(int nCommType, int nBdID);
bool CheckDriveErr(int nBdID);
bool SetServoOn(int nBdID);
bool JogMove(int nBdID, int nDir);

int main()
{
	int nBdID = 0;

	// Device Connect
	if (Connect(TCP, nBdID) == false)
	{
		getchar();
		exit(1);
	}

	// Drive Error Check
	if (CheckDriveErr(nBdID) == false)
	{
		getchar();
		exit(1);
	}

	// ServoOn 
	if (SetServoOn(nBdID) == false)
	{
		getchar();
		exit(1);
	}

	// Jogmode Move(CW)
	if (JogMove(nBdID, CW) == false)
	{
		getchar();
		exit(1);
	}

	// Jogmode Move(CCW)
	if (JogMove(nBdID, CCW) == false)
	{
		getchar();
		exit(1);
	}

	// Connection Close
	FAS_Close(nBdID);

	getchar();
}

bool Connect(int nCommType, int nBdID)
{
	unsigned char byIP[4] = { 192, 168, 0, 2 }; // IP : 192.168.0.2
	bool bSuccess = true;

	// Connection
	switch (nCommType)
	{
	case TCP:
		// TCP Connection
		if (FAS_ConnectTCP(byIP[0], byIP[1], byIP[2], byIP[3], nBdID) == 0)
		{
			printf("TCP Connection Fail! \n");
			bSuccess = false;
		}
		break;

	case UDP:
		// UDP Connection
		if (FAS_Connect(byIP[0], byIP[1], byIP[2], byIP[3], nBdID) == 0)
		{
			printf("UDP Connection Fail! \n");
			bSuccess = false;
		}
		break;

	default:
		printf("Wrong communication type. \n");
		bSuccess = false;

		break;
	}

	if (bSuccess)
		printf("Connected successfully. \n");

	return bSuccess;
}

bool CheckDriveErr(int nBdID)
{
	// Check Drive's Error
	EZISERVO2_AXISSTATUS AxisStatus;

	if (FAS_GetAxisStatus(nBdID, &(AxisStatus.dwValue)) != FMM_OK)
	{
		printf("Function(FAS_GetAxisStatus) was failed.\n");
		return false;
	}

	if (AxisStatus.FFLAG_ERRORALL)
	{
		// if Drive's Error was detected, Reset the ServoAlarm
		if (FAS_ServoAlarmReset(nBdID) != FMM_OK)
		{
			printf("Function(FAS_ServoAlarmReset) was failed.\n");
			return false;
		}
	}

	return true;
}

bool SetServoOn(int nBdID)
{
	// Check Drive's Servo Status
	EZISERVO2_AXISSTATUS AxisStatus;

	// if ServoOnFlagBit is OFF('0'), switch to ON('1')
	if (FAS_GetAxisStatus(nBdID, &(AxisStatus.dwValue)) != FMM_OK)
	{
		printf("Function(FAS_GetAxisStatus) was failed.\n");
		return false;
	}

	if (AxisStatus.FFLAG_SERVOON == 0)
	{
		if (FAS_ServoEnable(nBdID, 1) != FMM_OK)
		{
			printf("Function(FAS_ServoEnable) was failed.\n");
			return false;
		}

		do
		{
			usleep(1000);

			if (FAS_GetAxisStatus(nBdID, &(AxisStatus.dwValue)) != FMM_OK)
			{
				printf("Function(FAS_GetAxisStatus) was failed.\n");
				return false;
			}

			if (AxisStatus.FFLAG_SERVOON)
				printf("Servo ON \n");
		}
		while (!AxisStatus.FFLAG_SERVOON); // Wait until FFLAG_SERVOON is ON
	}
	else
	{
		printf("Servo is already ON \n");
	}

	return true;
}

bool JogMove(int nBdID, int nDir)
{
	// Jogmode Move 
	int nTargetVeloc = 10000;
	int nDirect = nDir;
	int nSeconds = 5 * 1000;

	EZISERVO2_AXISSTATUS AxisStatus;

	printf("---------------------------\n");
	if (FAS_MoveVelocity(nBdID, nTargetVeloc, nDirect) != FMM_OK)
	{
		printf("Function(FAS_MoveVelocity) was failed.\n");
		return false;
	}

	printf("Move Motor! \n");

	usleep(nSeconds*1000);

	if (FAS_MoveStop(nBdID) != FMM_OK)
	{
		printf("Function(FAS_MoveStop) was failed.\n");
		return false;
	}

	do
	{
		// Wait until FFLAG_MOTIONING is OFF
		usleep(1000);

		if (FAS_GetAxisStatus(nBdID, &(AxisStatus.dwValue)) != FMM_OK)
		{
			printf("Function(FAS_GetAxisStatus) was failed.\n");
			return false;
		}

		if (AxisStatus.FFLAG_MOTIONING == 0)
		{
			printf("Move Stop! \n");
		}
	}
	while (AxisStatus.FFLAG_MOTIONING);

	return true;
}
