# JogMovementExam 예제

## 1. 드라이브 에러 상태 확인

``` c++
// Check Drive's Error
EZISERVO2_AXISSTATUS AxisStatus;

if (FAS_GetAxisStatus(nBdID, &(AxisStatus.dwValue)) != FMM_OK)
{
	printf("Function(FAS_GetAxisStatus) was failed.\n");
	return false;
}

if (AxisStatus.FFLAG_ERRORALL)
{
	// if Drive's Error was detected, Reset the ServoAlarm
	if (FAS_ServoAlarmReset(nBdID) != FMM_OK)
	{
		printf("Function(FAS_ServoAlarmReset) was failed.\n");
		return false;
	}
}
```

FAS_GetAxisStatus() 함수를 사용하여 현재 드라이브의 운전 상태를 확인 할 수 있습니다. FAS_ServoAlarmReset() 함수를 사용하여 현재 드라이브의 알람상태를 리셋 할 수 있습니다.

### 1.1 드라이브 상태값

EZISERVO2_AXISSTATUS 는 드라이브 상태값이 정리된 구조체이며 헤더파일 (MOTION_EziSERVO2_DEFINE.h)에서 확인하실 수 있습니다.

## 2. Servo ON 제어

``` c++
if (FAS_ServoEnable(nBdID, TRUE) != FMM_OK)
{
	printf("Function(FAS_ServoEnable) was failed.\n");
	return false;
}
```

FAS_ServoEnable() 함수를 사용하여 드라이브의 Servo Enable 신호를 설정할 수 있습니다.

## 3. 드라이브 상태 감시

``` c++
EZISERVO2_AXISSTATUS AxisStatus;

do
{
	Sleep(1);
	
	if (FAS_GetAxisStatus(nBdID, &(AxisStatus.dwValue)) != FMM_OK)
	{
		printf("Function(FAS_GetAxisStatus) was failed.\n");
		return false;
	}

	if (AxisStatus.FFLAG_SERVOON)
		printf("Servo ON \n");
} while (!AxisStatus.FFLAG_SERVOON); // Wait until FFLAG_SERVOON is ON
```

드라이브의 운전 상태값을 나타내는 FAS_GetAxisStatus() 함수를 사용하여 사용자가 원하는 특정상태 값이 확인 될 때까지 대기할 수 있습니다.

## 4. 모터 동작 제어

``` c++
int nTargetVeloc = 10000;
int nDirect = nDir;
// #define CW  1
// #define CCW 0

if (FAS_MoveVelocity(nBdID, nTargetVeloc, nDirect) != FMM_OK)
{
	printf("Function(FAS_MoveVelocity) was failed.\n");
	return false;
}
```

FAS_MoveVelocity() 함수를 사용하여 사용자가 원하는 모터의 [속도, 방향]으로 동작할 수 있습니다.

## 5. 모터 정지

``` c++
if (FAS_MoveStop(nBdID) != FMM_OK)
{
	printf("Function(FAS_MoveStop) was failed.\n");
	return false;
}
```

FAS_MoveStop() 함수를 사용하여 동작중인 모터를 정지 할 수 있습니다.

## 6. 예제 프로그램 시나리오 설명

해당 예제프로그램의 시나리오는 아래와 같습니다.

1. 장치 연결.
2. 드라이브 에러 체크.
3. 드라이브 Servo ON.
4. 일정 시간동안(5초) 시계방향으로 모터 동작후 정지.
5. 일정 시간동안(5초) 반시계방향으로 모터 동작후 정지.
6. 연결 해제.

## 7. 기타

1. 장치 연결 및 해제에 관한 기능 설명은 [01.ConnectionExam] 프로젝트 문서를 참고하시기 바랍니다.
