# JogMovementExExam 예제

## 1. 드라이브 에러 상태 확인

``` c++
// Check Drive's Error
EZISERVO2_AXISSTATUS AxisStatus;

if (FAS_GetAxisStatus(nBdID, &(AxisStatus.dwValue)) != FMM_OK)
{
	printf("Function(FAS_GetAxisStatus) was failed.\n");
	return false;
}

if (AxisStatus.FFLAG_ERRORALL)
{
	// if Drive's Error was detected, Reset the ServoAlarm
	if (FAS_ServoAlarmReset(nBdID) != FMM_OK)
	{
		printf("Function(FAS_ServoAlarmReset) was failed.\n");
		return false;
	}
}
```

FAS_GetAxisStatus() 함수를 사용하여 현재 드라이브의 운전 상태를 확인 할 수 있습니다. FAS_ServoAlarmReset() 함수를 사용하여 현재 드라이브의 알람상태를 리셋 할 수 있습니다.

### 1.1 드라이브 상태값

EZISERVO2_AXISSTATUS 는 드라이브 상태값이 정리된 구조체이며 헤더파일 (MOTION_EziSERVO2_DEFINE.h)에서 확인하실 수 있습니다.

## 2. Servo ON 제어

``` c++
if (FAS_ServoEnable(nBdID, TRUE) != FMM_OK)
{
	printf("Function(FAS_ServoEnable) was failed.\n");
	return false;
}
```

FAS_ServoEnable() 함수를 사용하여 드라이브의 Servo Enable 신호를 설정할 수 있습니다.

## 3. 드라이브 상태 감시

``` c++
EZISERVO2_AXISSTATUS AxisStatus;

do
{
	Sleep(1);

	if (FAS_GetAxisStatus(nBdID, &(AxisStatus.dwValue)) != FMM_OK)
	{
		printf("Function(FAS_GetAxisStatus) was failed.\n");
		return false;
	}

	if (AxisStatus.FFLAG_SERVOON)
		printf("Servo ON \n");
} while (!AxisStatus.FFLAG_SERVOON); // Wait until FFLAG_SERVOON is ON
```

드라이브의 운전 상태값을 나타내는 FAS_GetAxisStatus() 함수를 사용하여 사용자가 원하는 특정상태 값이 확인 될 때까지 대기할 수 있습니다.

## 4. Parameter 값 설정

``` c++
// Set Jog Acc/Dec Time
if (FAS_SetParameter(nBdID, SERVO2_JOGACCDECTIME, nAccDecTime) != FMM_OK)
{
	printf("Function(FAS_SetParameter) was failed.\n");
	return false;
}
```

FAS_SetParameter 함수를 사용하여 파라미터의 값을 변경할 수 있습니다.

파라미터의 값은 설정하는 즉시 적용됩니다.

### 4.1 Jog 운전 설정 값

SERVO2_JOGACCDECTIME는 Jog 운전에 대한 설정 파라미터 번호입니다.

설정하고자 하는 파라미터의 번호는 해당하는 header 파일(Ezi-SERVOII Plus-E의 경우 MOTION_SERVO2_DEFINE.h)에서 확인하실 수 있습니다. 혹은, Ezi-MOTION Plus-E 프로그램의 Parameter List 화면에 표시되는 번호를 참고하시기 바랍니다.

## 5. 모터 동작 제어1

``` c++
int nTargetVeloc = 10000;
int nDirect = 1;
// #define CW  1
// #define CCW 0

if (FAS_MoveVelocity(nBdID, nTargetVeloc, nDirect) != FMM_OK)
{
	printf("Function(FAS_MoveVelocity) was failed.\n");
	return false;
}
```

FAS_MoveVelocity() 함수를 사용하여 사용자가 원하는 모터의 [속도, 방향]으로 동작할 수 있습니다.

## 6. 모터 동작 제어2

``` c++
// Set velocity
int nDirect = 1;
int lVelocity = 30000;

VELOCITY_OPTION_EX opt = { 0 };

// set user setting bit(BIT_USE_CUSTOMACCDEC) and acel/decel time value
opt.flagOption.BIT_USE_CUSTOMACCDEC = 1;
opt.wCustomAccDecTime = nAccDecTime;

printf("-----------------------------------------------------------\n");
if (FAS_MoveVelocityEx(nBdID, lVelocity, nDirect, &opt) != FMM_OK)
{
	printf("Function(FAS_MoveVelocityEx) was failed.\n");
	return false;
}
```

FAS_MoveVelocityEx() 함수를 사용하여 사용자가 원하는 모터의 [속도, 방향, 가속도]으로 동작할 수 있습니다.

### 6.1 사용자 옵션

VELOCITY_OPTION_EX는 모터 동작시 가감속 시간을 설정할 수 있는 구조체 변수입니다.

## 7. 모터 정지

``` c++
if (FAS_MoveStop(nBdID) != FMM_OK)
{
	printf("Function(FAS_MoveStop) was failed.\n");
	return false;
}
```

FAS_MoveStop() 함수를 사용하여 동작중인 모터를 정지 할 수 있습니다.

## 8. 예제 프로그램 시나리오 설명

해당 예제프로그램의 시나리오는 아래와 같습니다.

1. 장치 연결.
2. 드라이브 에러 체크.
3. 드라이브 Servo ON.
4. 가감속 파라미터 설정을 통한 모터 동작 실시. (3초)
5. 가감속 구조체 변수 설정을 통한 모터 동작 실시. (3초)
6. 연결 해제.

## 9. 기타

1. 장치 연결 및 해제에 대한 함수 설명은 [01.ConnectionExam] 프로젝트 문서를 참고하시기 바랍니다.

2. 파라미터 설정에 대한 함수 설명은 [02.ParameterTestExam] 프로젝트 문서를 참고하시기 바랍니다.
