MoveAbsIncPosExam 예제
======================

## 1. 드라이브 에러 상태 확인
----------------------------

``` c++
// Check Drive's Error
EZISERVO2_AXISSTATUS AxisStatus;

if (FAS_GetAxisStatus(nBdID, &(AxisStatus.dwValue)) != FMM_OK)
{
	printf("Function(FAS_GetAxisStatus) was failed.\n");
	return false;
}

if (AxisStatus.FFLAG_ERRORALL)
{
	// if Drive's Error was detected, Reset the ServoAlarm
	if (FAS_ServoAlarmReset(nBdID) != FMM_OK)
	{
		printf("Function(FAS_ServoAlarmReset) was failed.\n");
		return false;
	}
}
```

FAS_GetAxisStatus() 함수를 사용하여 현재 드라이브의 운전 상태를 확인 할 수 있습니다. FAS_ServoAlarmReset() 함수를 사용하여 현재 드라이브의 알람상태를 리셋 할 수 있습니다.

### 1.1 드라이브 상태값

EZISERVO2_AXISSTATUS 는 드라이브 상태값이 정리된 구조체이며 헤더파일 (MOTION_EziSERVO2_DEFINE.h)에서 확인하실 수 있습니다.

## 2. Servo ON 제어
------------------

``` c++
if (FAS_ServoEnable(nBdID, TRUE) != FMM_OK)
{
	printf("Function(FAS_ServoEnable) was failed.\n");
	return false;
}
```

FAS_ServoEnable() 함수를 사용하여 드라이브의 Servo Enable 신호를 설정할 수 있습니다.

## 3. 모터 상대 위치 이동 제어
-----------------------------

``` c++
int lIncPos = 370000;
int lVelocity = 40000;

if (FAS_MoveSingleAxisIncPos(nBdID, lIncPos, lVelocity) != FMM_OK)
{
	printf("Function(FAS_MoveSingleAxisIncPos) was failed.\n");
	return false;
}
```

FAS_MoveSingleAxisIncPos() 함수를 사용하여 모터의 [상대 위치, 속도]으로 동작시킬 수 있습니다.

## 4. 모터 절대 위치 이동 제어
-----------------------------

``` c++
int lAbsPos = 0;
int lVelocity = 40000;

// Move the motor by 0 pulse (target position : Absolute position)
if (FAS_MoveSingleAxisAbsPos(nBdID, lAbsPos, lVelocity) != FMM_OK)
{
	printf("Function(FAS_MoveSingleAxisAbsPos) was failed.\n");
	return false;
}
```

FAS_MoveSingleAxisAbsPos() 함수를 사용하여 모터의 [절대위치, 속도]으로 동작시킬 수 있습니다.

## 5. 드라이브 상태 감시
-----------------------

``` c++
EZISERVO2_AXISSTATUS AxisStatus;

// Check the Axis status until motor stops and the Inposition value is checked
do
{
	Sleep(1);

	if (FAS_GetAxisStatus(nBdID, &(AxisStatus.dwValue)) != FMM_OK)
	{
		printf("Function(FAS_GetAxisStatus) was failed.\n");
		return false;
	}

} while (AxisStatus.FFLAG_MOTIONING || !(AxisStatus.FFLAG_INPOSITION));
```

드라이브의 운전 상태값을 나타내는 FAS_GetAxisStatus() 함수를 사용하여 사용자가 원하는 특정상태 값이 확인 될 때까지 대기할 수 있습니다.

### 5.1 드라이브 상태값

EZISERVO2_AXISSTATUS 는 드라이브 상태값이 정리된 구조체이며 헤더파일 (MOTION_EziSERVO2_DEFINE.h)에서 확인하실 수 있습니다.

더하여 모터의 동작 후 정지완료 상태는 FFLAG_MOTIONING ('0') 및 FFLAG_INPOSITION('1') 값으로 확인 할 수 있습니다.

## 6. 예제 프로그램 시나리오 설명
--------------------------------

해당 예제프로그램의 시나리오는 아래와 같습니다.

1. 장치 연결.
2. 드라이브 에러 체크.
3. 드라이브 Servo ON.
4. 상대 위치 이동.
5. 절대 위치 이동.
6. 연결 해제.

## 7. 기타
---------

1. 장치 연결 및 해제에 관한 기능 설명은 [01.ConnectionExam] 프로젝트 문서를 참고하시기 바랍니다.
