#include <iostream>
#include <unistd.h>
#include "../Include/FAS_EziMOTIONPlusE.h"

using namespace PE;

#define TCP 0
#define UDP 1

bool Connect(int nCommType, int nBdID);
bool CheckDriveErr(int nBdID);
bool SetServoOn(int nBdID);
bool MovePos(int nBdID, int nDistance, int nAccDecTime);
bool MovePosEx(int nBdID, int nDistance, int nAccDecTime);

int main()
{
	int nBdID = 0;
	int distance;
	int accdec;

	// Device Connect
	if (Connect(TCP, nBdID) == false)
	{
		getchar();
		exit(1);
	}

	// Drive Error Check
	if (CheckDriveErr(nBdID) == false)
	{
		getchar();
		exit(1);
	}

	// ServoOn 
	if (SetServoOn(nBdID) == false)
	{
		getchar();
		exit(1);
	}

	/* SetParameter and Move */

	// AccDecTime = 100 ms
	distance = 100000;
	accdec = 100;
	if (MovePos(nBdID, distance, accdec) == false)
	{
		getchar();
		exit(1);
	}

	// AccDecTime = 200 ms
	distance = -100000;
	accdec = 200;
	if (MovePos(nBdID, distance, accdec) == false)
	{
		getchar();
		exit(1);
	}

	// AccDecTime = 300 ms
	distance = 100000;
	accdec = 300;
	if (MovePos(nBdID, distance, accdec) == false)
	{
		getchar();
		exit(1);
	}

	/* MoveEx */

	// AccDecTime = 100 ms
	distance = -100000;
	accdec = 100;
	if (MovePosEx(nBdID, distance, accdec) == false)
	{
		getchar();
		exit(1);
	}

	// AccDecTime = 200 ms
	distance = 100000;
	accdec = 200;
	if (MovePosEx(nBdID, distance, accdec) == false)
	{
		getchar();
		exit(1);
	}

	// AccDecTime = 300 ms
	distance = -100000;
	accdec = 300;
	if (MovePosEx(nBdID, distance, accdec) == false)
	{
		getchar();
		exit(1);
	}

	// Connection Close
	FAS_Close(nBdID);

	getchar();
}

bool Connect(int nCommType, int nBdID)
{
	unsigned char byIP[4] = { 192, 168, 0, 2 }; // IP : 192.168.0.2
	bool bSuccess = true;

	// Connection
	switch (nCommType)
	{
	case TCP:
		// TCP Connection
		if (FAS_ConnectTCP(byIP[0], byIP[1], byIP[2], byIP[3], nBdID) == 0)
		{
			printf("TCP Connection Fail! \n");
			bSuccess = false;
		}
		break;

	case UDP:
		// UDP Connection
		if (FAS_Connect(byIP[0], byIP[1], byIP[2], byIP[3], nBdID) == 0)
		{
			printf("UDP Connection Fail! \n");
			bSuccess = false;
		}
		break;

	default:
		printf("Wrong communication type. \n");
		bSuccess = false;

		break;
	}

	if (bSuccess)
		printf("Connected successfully. \n");

	return bSuccess;
}

bool CheckDriveErr(int nBdID)
{
	// Check Drive's Error
	EZISERVO2_AXISSTATUS AxisStatus;

	if (FAS_GetAxisStatus(nBdID, &(AxisStatus.dwValue)) != FMM_OK)
	{
		printf("Function(FAS_GetAxisStatus) was failed.\n");
		return false;
	}

	if (AxisStatus.FFLAG_ERRORALL)
	{
		// if Drive's Error was detected, Reset the ServoAlarm
		if (FAS_ServoAlarmReset(nBdID) != FMM_OK)
		{
			printf("Function(FAS_ServoAlarmReset) was failed.\n");
			return false;
		}
	}

	return true;
}

bool SetServoOn(int nBdID)
{
	// Check Drive's Servo Status
	EZISERVO2_AXISSTATUS AxisStatus;

	// if ServoOnFlagBit is OFF('0'), switch to ON('1')
	if (FAS_GetAxisStatus(nBdID, &(AxisStatus.dwValue)) != FMM_OK)
	{
		printf("Function(FAS_GetAxisStatus) was failed.\n");
		return false;
	}

	if (AxisStatus.FFLAG_SERVOON == 0)
	{
		if (FAS_ServoEnable(nBdID, 1) != FMM_OK)
		{
			printf("Function(FAS_ServoEnable) was failed.\n");
			return false;
		}

		do
		{
			usleep(1000);

			if (FAS_GetAxisStatus(nBdID, &(AxisStatus.dwValue)) != FMM_OK)
			{
				printf("Function(FAS_GetAxisStatus) was failed.\n");
				return false;
			}

			if (AxisStatus.FFLAG_SERVOON)
				printf("Servo ON \n");
		}
		while (!AxisStatus.FFLAG_SERVOON); // Wait until FFLAG_SERVOON is ON
	}
	else
	{
		printf("Servo is already ON \n");
	}

	return true;
}

bool MovePos(int nBdID, int nDistance, int nAccDecTime)
{
	// SetParameter & MoveSingleAxisIncPos

	EZISERVO2_AXISSTATUS AxisStatus;
	int lIncPos;
	int lVelocity;

	// Set Acc Time
	if (FAS_SetParameter(nBdID, SERVO2_AXISACCTIME, nAccDecTime) != FMM_OK)
	{
		printf("Function(FAS_SetParameter) was failed.\n");
		return false;
	}

	// Set Dec Time
	if (FAS_SetParameter(nBdID, SERVO2_AXISDECTIME, nAccDecTime) != FMM_OK)
	{
		printf("Function(FAS_SetParameter) was failed.\n");
		return false;
	}

	printf("---------------------------\n");

	// Move the motor by [nDistance] pulse (target position : Absolute position)
	lIncPos = nDistance;
	lVelocity = 40000;

	printf("Move Motor! \n");
	if (FAS_MoveSingleAxisIncPos(nBdID, lIncPos, lVelocity) != FMM_OK)
	{
		printf("Function(FAS_MoveSingleAxisIncPos) was failed.\n");
		return false;
	}

	// Check the Axis status until FFLAG_MOTIONING is ON
	do
	{
		usleep(1000);

		if (FAS_GetAxisStatus(nBdID, &(AxisStatus.dwValue)) != FMM_OK)
		{
			printf("Function(FAS_GetAxisStatus) was failed.\n");
			return false;
		}

	}
	while (AxisStatus.FFLAG_MOTIONING);

	return true;
}

bool MovePosEx(int nBdID, int nDistance, int nAccDecTime)
{
	// MoveSingleAxisIncPosEx
	EZISERVO2_AXISSTATUS AxisStatus;
	MOTION_OPTION_EX opt = { 0 };
	int lIncPos;
	int lVelocity;

	printf("---------------------------\n");

	lIncPos = nDistance;
	lVelocity = 40000;
	opt.flagOption.BIT_USE_CUSTOMACCEL = 1;
	opt.flagOption.BIT_USE_CUSTOMDECEL = 1;
	opt.wCustomAccelTime = nAccDecTime;
	opt.wCustomDecelTime = nAccDecTime;

	printf("Move Motor! [Ex]\n");
	if (FAS_MoveSingleAxisIncPosEx(nBdID, lIncPos, lVelocity, &opt) != FMM_OK)
	{
		printf("Function(FAS_MoveSingleAxisIncPosEx) was failed.\n");
		return false;
	}

	// Check the Axis status until motor stops and the Inposition value is checked
	do
	{
		usleep(1000);

		if (FAS_GetAxisStatus(nBdID, &(AxisStatus.dwValue)) != FMM_OK)
		{
			printf("Function(FAS_GetAxisStatus) was failed.\n");
			return false;
		}

	}
	while (AxisStatus.FFLAG_MOTIONING || !(AxisStatus.FFLAG_INPOSITION));

	return true;
}
