VelocityOverrideExam 예제
=========================

## 1. 드라이브 에러 상태 확인
----------------------------

``` c++
// Check Drive's Error
EZISERVO2_AXISSTATUS AxisStatus;

if (FAS_GetAxisStatus(nBdID, &(AxisStatus.dwValue)) != FMM_OK)
{
	printf("Function(FAS_GetAxisStatus) was failed.\n");
	return false;
}

if (AxisStatus.FFLAG_ERRORALL)
{
	// if Drive's Error was detected, Reset the ServoAlarm
	if (FAS_ServoAlarmReset(nBdID) != FMM_OK)
	{
		printf("Function(FAS_ServoAlarmReset) was failed.\n");
		return false;
	}
}
```

FAS_GetAxisStatus() 함수를 사용하여 현재 드라이브의 운전 상태를 확인 할 수 있습니다. FAS_ServoAlarmReset() 함수를 사용하여 현재 드라이브의 알람상태를 리셋 할 수 있습니다.

### 1.1 드라이브 상태값

EZISERVO2_AXISSTATUS 는 드라이브 상태값이 정리된 구조체이며 헤더파일 (MOTION_EziSERVO2_DEFINE.h)에서 확인하실 수 있습니다.

## 2. Servo ON 제어
------------------

``` c++
if (FAS_ServoEnable(nBdID, TRUE) != FMM_OK)
{
	printf("Function(FAS_ServoEnable) was failed.\n");
	return false;
}
```

FAS_ServoEnable() 함수를 사용하여 드라이브의 Servo Enable 신호를 설정할 수 있습니다.

## 3. 현재 위치값 얻기
---------------------

``` c++
int lActualPos = 0;

if (FAS_GetActualPos(nBdID, &lActualPos) != FMM_OK)
{
	printf("Function(FAS_GetActualPos) was failed.\n");
	return false;
}
```

FAS_GetActualPos() 함수를 사용하여 현재 모터의 절대위치값을 파악할 수 있습니다.

## 4. 현재 속도값 확인

``` c++
int lActualVelocity = 0;

if (FAS_GetActualVel(nBdID, &lActualVelocity) != FMM_OK)
{
	printf("Function(FAS_GetActualVel) was failed. \n");
	return false;
}
```

FAS_GetActualVel() 함수를 사용하여 현재 모터의 속값을 파악할 수 있습니다.

## 5. 속도 변경 제어
-------------------

``` c++
int lVelocity = 20000;
int lChangeVelocity = 0;

lChangeVelocity = lVelocity * 2;
if (FAS_VelocityOverride(nBdID, lChangeVelocity) != FMM_OK)
{
	printf("Function(FAS_VelocityOverride) was failed.\n");
	return false;
}
```

FAS_VelocityOverride() 함수를 사용하여 모터에 이미 설정된 속도값을 변경하는데 사용할 수 있습니다.

## 6. 모터 정지
--------------

``` c++
FAS_MoveStop(nBdID);
printf("FAS_MoveStop! \n");
```

FAS_MoveStop() 함수를 사용하여 동작중인 모터를 정지 할 수 있습니다.

## 7. 예제 프로그램 시나리오 설명
--------------------------------

해당 예제프로그램의 시나리오는 아래와 같습니다.

1. 장치 연결.
2. 드라이브 에러 체크.
3. 드라이브 Servo ON.
4. 상대 위치 이동 운전으로 모터를 구동시키며 사용자가 지정한 특정 지점에 도달하게 된다면 기존의 모터 속도를 변경하여 구동시킵니다.
5. 기본 모터 구동 운전을 진행하며 일정 시간이 지나면 사용자가 지정한 속도로 변화시키며 운전을 진행합니다.
6. 연결 해제.

## 8. 기타
---------

1. 장치 연결 및 해제에 대한 함수 설명은 [01.ConnectionExam] 프로젝트 문서를 참고하시기 바랍니다.

2. 기본 모터 구동 운전에 대한 함수 설명은 [05.JogMovementExam] 프로젝트 문서를 참고하시기 바랍니다.

3. 상대 위치 이동 운전에 대한 함수 설명은 [07.MoveAbsIncPosExam] 프로젝트 문서를 참고하시기 바랍니다.
