﻿#include <iostream>
#include <unistd.h>
#include "../Include/FAS_EziMOTIONPlusE.h"

using namespace PE;
using std::string;

#define TCP 0
#define UDP 1

#define CW  0
#define CCW 1

bool Connect(int nCommType, int nBdID);
bool CheckDriveErr(int nBdID);
bool SetServoOn(int nBdID);
bool SetOriginParameter(int nBdID);
bool OriginSearch(int nBdID);

int main()
{
	int nBdID = 0;

	// Device Connect
	if (Connect(TCP, nBdID) == false)
	{
		getchar();
		exit(1);
	}

	// Drive Error Check
	if (CheckDriveErr(nBdID) == false)
	{
		getchar();
		exit(1);
	}

	// ServoOn 
	if (SetServoOn(nBdID) == false)
	{
		getchar();
		exit(1);
	}

	// Set Origin Parameter
	if (SetOriginParameter(nBdID) == false)
	{
		getchar();
		exit(1);
	}

	// Act Origin Search Function
	if (OriginSearch(nBdID) == false)
	{
		getchar();
		exit(1);
	}

	// Connection Close
	FAS_Close(nBdID);

	getchar();
}

bool Connect(int nCommType, int nBdID)
{
	unsigned char byIP[4] = { 192, 168, 0, 2 }; // IP : 192.168.0.2
	bool bSuccess = true;

	// Connection
	switch (nCommType)
	{
	case TCP:
		// TCP Connection
		if (FAS_ConnectTCP(byIP[0], byIP[1], byIP[2], byIP[3], nBdID) == 0)
		{
			printf("TCP Connection Fail! \n");
			bSuccess = false;
		}
		break;

	case UDP:
		// UDP Connection
		if (FAS_Connect(byIP[0], byIP[1], byIP[2], byIP[3], nBdID) == 0)
		{
			printf("UDP Connection Fail! \n");
			bSuccess = false;
		}
		break;

	default:
		printf("Wrong communication type. \n");
		bSuccess = false;

		break;
	}

	if (bSuccess)
		printf("Connected successfully. \n");

	return bSuccess;
}

bool CheckDriveErr(int nBdID)
{
	// Check Drive's Error
	EZISERVO2_AXISSTATUS AxisStatus;

	if (FAS_GetAxisStatus(nBdID, &(AxisStatus.dwValue)) != FMM_OK)
	{
		printf("Function(FAS_GetAxisStatus) was failed.\n");
		return false;
	}

	if (AxisStatus.FFLAG_ERRORALL)
	{
		// if Drive's Error was detected, Reset the ServoAlarm
		if (FAS_ServoAlarmReset(nBdID) != FMM_OK)
		{
			printf("Function(FAS_ServoAlarmReset) was failed.\n");
			return false;
		}
	}

	return true;
}

bool SetServoOn(int nBdID)
{
	// Check Drive's Servo Status
	EZISERVO2_AXISSTATUS AxisStatus;

	// if ServoOnFlagBit is OFF('0'), switch to ON('1')
	if (FAS_GetAxisStatus(nBdID, &(AxisStatus.dwValue)) != FMM_OK)
	{
		printf("Function(FAS_GetAxisStatus) was failed.\n");
		return false;
	}

	if (AxisStatus.FFLAG_SERVOON == 0)
	{
		if (FAS_ServoEnable(nBdID, 1) != FMM_OK)
		{
			printf("Function(FAS_ServoEnable) was failed.\n");
			return false;
		}

		do
		{
			usleep(1000);

			if (FAS_GetAxisStatus(nBdID, &(AxisStatus.dwValue)) != FMM_OK)
			{
				printf("Function(FAS_GetAxisStatus) was failed.\n");
				return false;
			}

			if (AxisStatus.FFLAG_SERVOON)
				printf("Servo ON \n");
		}
		while (!AxisStatus.FFLAG_SERVOON); // Wait until FFLAG_SERVOON is ON
	}
	else
	{
		printf("Servo is already ON \n");
	}

	return true;
}

bool SetOriginParameter(int nBdID)
{
	// Set Origin Parameter
	int nOrgSpeed = 50000;
	int nOrgSearchSpeed = 1000;
	int nOrgAccDecTime = 50;
	int nOrgMethod = 2;	// Origin Method = 2 is 'Limit Origin' in the Ezi-SERVOII Plus-E model.
	int nOrgDir = CW;
	int nOrgOffset = 0;
	int nOrgPositionSet = 0;
	int nOrgTorqueRatio = 50;

	if (FAS_SetParameter(nBdID, SERVO2_ORGSPEED, nOrgSpeed) != FMM_OK)
	{
		printf("Function(FAS_SetParameter[SERVO2_ORGSPEED]) was failed.\n");
		return false;
	}

	if (FAS_SetParameter(nBdID, SERVO2_ORGSEARCHSPEED, nOrgSearchSpeed) != FMM_OK)
	{
		printf("Function(FAS_SetParameter[SERVO2_ORGSEARCHSPEED]) was failed.\n");
		return false;
	}

	if (FAS_SetParameter(nBdID, SERVO2_ORGACCDECTIME, nOrgAccDecTime) != FMM_OK)
	{
		printf("Function(FAS_SetParameter[SERVO2_ORGACCDECTIME]) was failed.\n");
		return false;
	}

	if (FAS_SetParameter(nBdID, SERVO2_ORGMETHOD, nOrgMethod) != FMM_OK)
	{
		printf("Function(FAS_SetParameter[SERVO2_ORGMETHOD]) was failed.\n");
		return false;
	}

	if (FAS_SetParameter(nBdID, SERVO2_ORGDIR, nOrgDir) != FMM_OK)
	{
		printf("Function(FAS_SetParameter[SERVO2_ORGDIR]) was failed.\n");
		return false;
	}

	if (FAS_SetParameter(nBdID, SERVO2_ORGOFFSET, nOrgOffset) != FMM_OK)
	{
		printf("Function(FAS_SetParameter[SERVO2_ORGOFFSET]) was failed.\n");
		return false;
	}

	if (FAS_SetParameter(nBdID, SERVO2_ORGPOSITIONSET, nOrgPositionSet) != FMM_OK)
	{
		printf("Function(FAS_SetParameter[SERVO2_ORGPOSITIONSET]) was failed.\n");
		return false;
	}

	if (FAS_SetParameter(nBdID, SERVO2_ORGTORQUERATIO, nOrgTorqueRatio) != FMM_OK)
	{
		printf("Function(FAS_SetParameter[SERVO2_ORGTORQUERATIO]) was failed.\n");
		return false;
	}

	return true;
}

bool OriginSearch(int nBdID)
{
	// Act Origin Search Function
	EZISERVO2_AXISSTATUS AxisStatus;

	printf("---------------------------\n");

	// Origin Search Start
	if (FAS_MoveOriginSingleAxis(nBdID) != FMM_OK)
	{
		printf("Function(FAS_MoveOriginSingleAxis) was failed.\n");
		return false;
	}

	// Check the Axis status until OriginReturning value is released.
	do
	{
		usleep(1000);

		if (FAS_GetAxisStatus(nBdID, &(AxisStatus.dwValue)) != FMM_OK)
		{
			printf("Function(FAS_GetAxisStatus) was failed.\n");
			return false;
		}

	}
	while (AxisStatus.FFLAG_ORIGINRETURNING);

	if (AxisStatus.FFLAG_ORIGINRETOK)
	{
		printf("Origin Search Success! \n");
		return true;
	}
	else
	{
		printf("Origin Search Fail !\n");
		return false;
	}
}
