OriginSearchExam 예제
=====================

## 1. 드라이브 에러 상태 확인
----------------------------

``` c++
// Check Drive's Error
EZISERVO2_AXISSTATUS AxisStatus;

if (FAS_GetAxisStatus(nBdID, &(AxisStatus.dwValue)) != FMM_OK)
{
	printf("Function(FAS_GetAxisStatus) was failed.\n");
	return false;
}

if (AxisStatus.FFLAG_ERRORALL)
{
	// if Drive's Error was detected, Reset the ServoAlarm
	if (FAS_ServoAlarmReset(nBdID) != FMM_OK)
	{
		printf("Function(FAS_ServoAlarmReset) was failed.\n");
		return false;
	}
}
```

FAS_GetAxisStatus() 함수를 사용하여 현재 드라이브의 운전 상태를 확인 할 수 있습니다. FAS_ServoAlarmReset() 함수를 사용하여 현재 드라이브의 알람상태를 리셋 할 수 있습니다.

### 1.1 드라이브 상태값

EZISERVO2_AXISSTATUS 는 드라이브 상태값이 정리된 구조체이며 헤더파일 (MOTION_EziSERVO2_DEFINE.h)에서 확인하실 수 있습니다.

## 2. Servo ON 제어
------------------

``` c++
if (FAS_ServoEnable(nBdID, TRUE) != FMM_OK)
{
	printf("Function(FAS_ServoEnable) was failed.\n");
	return false;
}
```

FAS_ServoEnable() 함수를 사용하여 드라이브의 Servo Enable 신호를 설정할 수 있습니다.

## 3. Parameter 값 설정
----------------------

``` c++
if (FAS_SetParameter(nBdID, SERVO2_ORGSPEED, nOrgSpeed) != FMM_OK)
{
	printf("Function(FAS_SetParameter[SERVO2_ORGSPEED]) was failed.\n");
	return false;
}

if (FAS_SetParameter(nBdID, SERVO2_ORGSEARCHSPEED, nOrgSearchSpeed) != FMM_OK)
{
	printf("Function(FAS_SetParameter[SERVO2_ORGSEARCHSPEED]) was failed.\n");
	return false;
}

if (FAS_SetParameter(nBdID, SERVO2_ORGACCDECTIME, nOrgAccDecTime) != FMM_OK)
{
	printf("Function(FAS_SetParameter[SERVO2_ORGACCDECTIME]) was failed.\n");
	return false;
}

if (FAS_SetParameter(nBdID, SERVO2_ORGMETHOD, nOrgMethod) != FMM_OK)
{
	printf("Function(FAS_SetParameter[SERVO2_ORGMETHOD]) was failed.\n");
	return false;
}

if (FAS_SetParameter(nBdID, SERVO2_ORGDIR, nOrgDir) != FMM_OK)
{
	printf("Function(FAS_SetParameter[SERVO2_ORGDIR]) was failed.\n");
	return false;
}

if (FAS_SetParameter(nBdID, SERVO2_ORGOFFSET, nOrgOffset) != FMM_OK)
{
	printf("Function(FAS_SetParameter[SERVO2_ORGOFFSET]) was failed.\n");
	return false;
}

if (FAS_SetParameter(nBdID, SERVO2_ORGPOSITIONSET, nOrgPositionSet) != FMM_OK)
{
	printf("Function(FAS_SetParameter[SERVO2_ORGPOSITIONSET]) was failed.\n");
	return false;
}

if (FAS_SetParameter(nBdID, SERVO2_ORGTORQUERATIO, nOrgTorqueRatio) != FMM_OK)
{
	printf("Function(FAS_SetParameter[SERVO2_ORGTORQUERATIO]) was failed.\n");
	return false;
}
```

FAS_SetParameter 함수를 사용하여 파라미터의 값을 변경할 수 있습니다.

파라미터의 값은 설정하는 즉시 적용됩니다.

### 3.1 원점 탐색 설정 값

SERVO2_ORGSPEED, SERVO2_ORGSEARCHSPEED, SERVO2_ORGACCDECTIME... 다양한 원점 탐색에 대한 설정값은 파라미터 번호입니다.

설정하고자 하는 파라미터의 번호는 해당하는 header 파일(Ezi-SERVOII Plus-E의 경우 MOTION_SERVO2_DEFINE.h)에서 확인하실 수 있습니다. 혹은, Ezi-MOTION Plus-E 프로그램의 Parameter List 화면에 표시되는 번호를 참고하시기 바랍니다.

## 4. 원점 탐색 동작 실시.
-------------------------

``` c++
// Origin Search Start
if (FAS_MoveOriginSingleAxis(nBdID) != FMM_OK)
{
	printf("Function(FAS_MoveOriginSingleAxis) was failed.\n");
	return false;
}
```

FAS_MoveOriginSingleAxis() 함수를 사용하여 사용자가 설정한 탐색 모드값에 따라 탐색이 시작됩니다.

## 5. 드라이브 상태 감시
-----------------------

``` c++
EZISERVO2_AXISSTATUS AxisStatus;

// Check the Axis status until OriginReturning value is released.
do
{
	Sleep(1);

	if (FAS_GetAxisStatus(nBdID, &(AxisStatus.dwValue)) != FMM_OK)
	{
		printf("Function(FAS_GetAxisStatus) was failed.\n");
		return false;
	}

} while (AxisStatus.FFLAG_ORIGINRETURNING);

if (AxisStatus.FFLAG_ORIGINRETOK)
{
	printf("Origin Search Success! \n");
	return true;
}
```

드라이브의 운전 상태값을 나타내는 FAS_GetAxisStatus() 함수를 사용하여 사용자가 원하는 특정상태 값이 확인 될 때까지 대기할 수 있습니다.

더하여 모터의 원점 탐색 완료 상태는 FFLAG_ORIGINRETURNING ('0') 및 FFLAG_ORIGINRETOK('1') 값으로 확인 할 수 있습니다.

## 6. 예제 프로그램 시나리오 설명
--------------------------------

해당 예제프로그램의 시나리오는 아래와 같습니다.

1. 장치 연결.
2. 드라이브 에러 체크.
3. 드라이브 Servo ON.
4. 원점 탐색 관련 파라미터 설정.
5. 모터 원점 탐색 실시.
6. 연결 해제.

## 7. 기타
---------

1. 장치 연결 및 해제에 대한 함수 설명은 [01.ConnectionExam] 프로젝트 문서를 참고하시기 바랍니다.

2. 파라미터 설정에 대한 함수 설명은 [02.ParameterTestExam] 프로젝트 문서를 참고하시기 바랍니다.
