SetPositionTableExam 예제
=========================

## 1. 드라이브 에러 상태 확인
----------------------------

``` c++
// Check Drive's Error
EZISERVO2_AXISSTATUS AxisStatus;

if (FAS_GetAxisStatus(nBdID, &(AxisStatus.dwValue)) != FMM_OK)
{
	printf("Function(FAS_GetAxisStatus) was failed.\n");
	return false;
}

if (AxisStatus.FFLAG_ERRORALL)
{
	// if Drive's Error was detected, Reset the ServoAlarm
	if (FAS_ServoAlarmReset(nBdID) != FMM_OK)
	{
		printf("Function(FAS_ServoAlarmReset) was failed.\n");
		return false;
	}
}
```

FAS_GetAxisStatus() 함수를 사용하여 현재 드라이브의 운전 상태를 확인 할 수 있습니다. FAS_ServoAlarmReset() 함수를 사용하여 현재 드라이브의 알람상태를 리셋 할 수 있습니다.

### 1.1 드라이브 상태값

EZISERVO2_AXISSTATUS 는 드라이브 상태값이 정리된 구조체이며 헤더파일 (MOTION_EziSERVO2_DEFINE.h)에서 확인하실 수 있습니다.

## 2. Servo ON 제어
------------------

``` c++
if (FAS_ServoEnable(nBdID, TRUE) != FMM_OK)
{
	printf("Function(FAS_ServoEnable) was failed.\n");
	return false;
}
```

FAS_ServoEnable() 함수를 사용하여 드라이브의 Servo Enable 신호를 설정할 수 있습니다.

## 3. 포지션 테이블 설정
-----------------------

``` c++
// Sets values in the position table.
ITEM_NODE nodeItem;
WORD wItemNo = 1;

// Overwrite part of node's data
nodeItem.dwMoveSpd = 50000;
nodeItem.lPosition = 250000;
nodeItem.wBranch = 3;
nodeItem.wContinuous = 1;

// Set node data in Position Table
if (FAS_PosTableWriteItem(nBdID, wItemNo, &nodeItem))
{
	printf("Function(FAS_PosTableWriteItem) was failed.\n");
	return false;
}
```

FAS_PosTableWriteItem() 함수를 사용하여 포지션 테이블을 구성하는 인덱스에 다양한 속성을 설정할 수 있습니다.

### 3.1 포지션 테이블 설정값

ITEM_NODE는 포지션 테이블을 구성하는 인덱스의 속성값이 정리된 구조체이며 헤더파일(MOTION_DEFINE.h)에서 확인하실 수 있습니다.

## 4. 포지션 테이블 설정 확인
----------------------------

``` c++
ITEM_NODE nodeItem;
WORD wItemNo = 1;

// Gets the data values of that node.
if (FAS_PosTableReadItem(nBdID, wItemNo, &nodeItem) != FMM_OK)
{
	printf("Function(FAS_PosTableReadItem) was failed.\n");
	return false;
}
```

FAS_PosTableReadItem() 함수를 사용하여 포지션 테이블내 특정 인덱스에 저장된 테이블 속성을 확인 할 수 있습니다.

## 5. 포지션 테이블 실행
-----------------------

``` c++
WORD wItemNo = 1;

if (FAS_PosTableRunItem(nBdID, wItemNo) != FMM_OK)
{
	printf("Function(FAS_PosTableRunItem) was failed.\n");
	return false;
}
```

FAS_PosTableRunItem() 함수를 사용하여 포지션 테이블내 특정 인덱스의 설정값에 맞게 동작시킬수 있습니다.

## 6. 드라이브 상태 감시
-----------------------

``` c++
EZISERVO2_AXISSTATUS AxisStatus;

do
{
	Sleep(1);

	if (FAS_GetAxisStatus(nBdID, &(AxisStatus.dwValue)) != FMM_OK)
	{
		printf("Function(FAS_GetAxisStatus) was failed.\n");
		return false;
	}

	if (AxisStatus.FFLAG_PTSTOPPED == true)
		printf("Position Table Run Stop! \n");
} while (!AxisStatus.FFLAG_PTSTOPPED);
```

드라이브의 운전 상태값을 나타내는 FAS_GetAxisStatus() 함수를 사용하여 사용자가 원하는 특정상태 값이 확인 될 때까지 대기할 수 있습니다.

더하여 포지션 테이블 동작 완료 상태는 FFLAG_ORIGINRETURNING ('0')값으로 확인 할 수 있습니다.

## 7. 예제 프로그램 시나리오 설명
--------------------------------

해당 예제프로그램의 시나리오는 아래와 같습니다.

1. 장치 연결.
2. 드라이브 에러 체크.
3. 드라이브 Servo ON.
4. 포지션 테이블 설정 및 확인 실시.
5. 포지션 테이블 실행.
6. 연결 해제.

## 8. 기타
---------

1. 장치 연결 및 해제에 대한 함수 설명은 [01.ConnectionExam] 프로젝트 문서를 참고하시기 바랍니다.
