#include <iostream>
#include <unistd.h>
#include "../Include/FAS_EziMOTIONPlusE.h"

using namespace PE;

#define TCP 0
#define UDP 1

#define STOPMODE 0 // stop mode(0)

#define RETURNPOS 0

bool Connect(int nCommType, int nBdID);
bool CheckDriveErr(int nBdID);
bool SetServoOn(int nBdID);
bool OperatePushMode(int nBdID);
bool ReturnPosition(int nBdID);
bool CheckPushResult(int nBdID);

int main()
{
	int nBdID = 0;

	// Device Connect
	if (Connect(TCP, nBdID) == false)
	{
		getchar();
		exit(1);
	}

	// Drive Error Check
	if (CheckDriveErr(nBdID) == false)
	{
		getchar();
		exit(1);
	}

	// ServoOn 
	if (SetServoOn(nBdID) == false)
	{
		getchar();
		exit(1);
	}

	// Operate PushMode
	if (OperatePushMode(nBdID) == false)
	{
		getchar();
		exit(1);
	}

	// Check PushMotion Result
	if (CheckPushResult(nBdID) == false)
	{
		getchar();
		exit(1);
	}

	// Return Position
	if (ReturnPosition(nBdID) == false)
	{
		getchar();
		exit(1);
	}

	// Connection Close
	FAS_Close(nBdID);

	getchar();
}

bool Connect(int nCommType, int nBdID)
{
	unsigned char byIP[4] = { 192, 168, 0, 2 }; // IP : 192.168.0.2
	bool bSuccess = true;

	// Connection
	switch (nCommType)
	{
	case TCP:
		// TCP Connection
		if (FAS_ConnectTCP(byIP[0], byIP[1], byIP[2], byIP[3], nBdID) == 0)
		{
			printf("TCP Connection Fail! \n");
			bSuccess = false;
		}
		break;

	case UDP:
		// UDP Connection
		if (FAS_Connect(byIP[0], byIP[1], byIP[2], byIP[3], nBdID) == 0)
		{
			printf("UDP Connection Fail! \n");
			bSuccess = false;
		}
		break;

	default:
		printf("Wrong communication type. \n");
		bSuccess = false;

		break;
	}

	if (bSuccess)
		printf("Connected successfully. \n");

	return bSuccess;
}

bool CheckDriveErr(int nBdID)
{
	// Check Drive's Error
	EZISERVO2_AXISSTATUS AxisStatus;

	if (FAS_GetAxisStatus(nBdID, &(AxisStatus.dwValue)) != FMM_OK)
	{
		printf("Function(FAS_GetAxisStatus) was failed.\n");
		return false;
	}

	if (AxisStatus.FFLAG_ERRORALL)
	{
		// if Drive's Error was detected, Reset the ServoAlarm
		if (FAS_ServoAlarmReset(nBdID) != FMM_OK)
		{
			printf("Function(FAS_ServoAlarmReset) was failed.\n");
			return false;
		}
	}

	return true;
}

bool SetServoOn(int nBdID)
{
	// Check Drive's Servo Status
	EZISERVO2_AXISSTATUS AxisStatus;

	// if ServoOnFlagBit is OFF('0'), switch to ON('1')
	if (FAS_GetAxisStatus(nBdID, &(AxisStatus.dwValue)) != FMM_OK)
	{
		printf("Function(FAS_GetAxisStatus) was failed.\n");
		return false;
	}

	if (AxisStatus.FFLAG_SERVOON == 0)
	{
		if (FAS_ServoEnable(nBdID, 1) != FMM_OK)
		{
			printf("Function(FAS_ServoEnable) was failed.\n");
			return false;
		}

		do
		{
			usleep(1000);

			if (FAS_GetAxisStatus(nBdID, &(AxisStatus.dwValue)) != FMM_OK)
			{
				printf("Function(FAS_GetAxisStatus) was failed.\n");
				return false;
			}

			if (AxisStatus.FFLAG_SERVOON)
				printf("Servo ON \n");
		}
		while (!AxisStatus.FFLAG_SERVOON); // Wait until FFLAG_SERVOON is ON
	}
	else
	{
		printf("Servo is already ON \n");
	}

	return true;
}

bool OperatePushMode(int nBdID)
{
	EZISERVO2_AXISSTATUS AxisStatus;
	unsigned int dwStartSpd, dwMoveSpd;
	unsigned short wAccel, wDecel;
	int lPosition;

	unsigned int dwPushSpd;
	unsigned short wPushRate;
	unsigned short wPushMode;
	int lEndPosition;

	// normal position motion
	dwStartSpd = 1;
	dwMoveSpd = 50000;
	wAccel = 500;
	wDecel = 500;
	lPosition = 500000;

	// push motion
	dwPushSpd = 2000;
	wPushRate = 50;
	wPushMode = 0;	// Stop Mode Push
	lEndPosition = lPosition + 10000;

	printf("---------------------------\n");

	if (FAS_MovePush(nBdID, dwStartSpd, dwMoveSpd, lPosition, wAccel, wDecel, wPushRate, dwPushSpd, lEndPosition, wPushMode) != FMM_OK)
	{
		printf("Function(FAS_MovePush) was failed.\n");
		return false;
	}

	// Check the Axis status until motor stops and the FFLAG_MOTIONING value is released.
	do
	{
		usleep(15*1000);

		if (FAS_GetAxisStatus(nBdID, &(AxisStatus.dwValue)) != FMM_OK)
		{
			printf("Function(FAS_GetAxisStatus) was failed.\n");
			return false;
		}

	}
	while (AxisStatus.FFLAG_MOTIONING);

	return true;
}

bool CheckPushResult(int nBdID)
{
	unsigned int dwOutput = 0;
	EZISERVO2_OUTLOGIC outLogic;

	printf("---------------------------\n");
	printf("Check Result Function\n");

	if (FAS_GetIOOutput(nBdID, &dwOutput) != FMM_OK)
	{
		printf("Function(FAS_GetIOOutput) was failed. \n");
		return false;
	}
	else
	{
		outLogic.dwValue = dwOutput;

		if (outLogic.BIT_PUSHDETECT == true)
			printf("Work Detected! \n");
		else
			printf("Work Not Detected! \n");
	}

	return true;
}

bool ReturnPosition(int nBdID)
{
	// Return Position
	EZISERVO2_AXISSTATUS AxisStatus;
	int lAbsPos;
	int lVelocity;

	// Move the motor by 0 pulse (target position : Absolute position)
	lAbsPos = 0;
	lVelocity = 50000;

	printf("---------------------------\n");
	printf("Return Postion Start! \n");
	if (FAS_MoveSingleAxisAbsPos(nBdID, lAbsPos, lVelocity) != FMM_OK)
	{
		printf("Function(FAS_MoveSingleAxisAbsPos) was failed.\n");
		return false;
	}

	// Check the Axis status until motor stops and the Inposition value is checked
	do
	{
		usleep(15*1000);

		if (FAS_GetAxisStatus(nBdID, &(AxisStatus.dwValue)) != FMM_OK)
		{
			printf("Function(FAS_GetAxisStatus) was failed.\n");
			return false;
		}

	}
	while (AxisStatus.FFLAG_MOTIONING || !(AxisStatus.FFLAG_INPOSITION));

	return true;
}
