PushNonStopExam 예제
====================

## 1. 드라이브 에러 상태 확인
----------------------------

``` c++
// Check Drive's Error
EZISERVO2_AXISSTATUS AxisStatus;

if (FAS_GetAxisStatus(nBdID, &(AxisStatus.dwValue)) != FMM_OK)
{
	printf("Function(FAS_GetAxisStatus) was failed.\n");
	return false;
}

if (AxisStatus.FFLAG_ERRORALL)
{
	// if Drive's Error was detected, Reset the ServoAlarm
	if (FAS_ServoAlarmReset(nBdID) != FMM_OK)
	{
		printf("Function(FAS_ServoAlarmReset) was failed.\n");
		return false;
	}
}
```

FAS_GetAxisStatus() 함수를 사용하여 현재 드라이브의 운전 상태를 확인 할 수 있습니다. FAS_ServoAlarmReset() 함수를 사용하여 현재 드라이브의 알람상태를 리셋 할 수 있습니다.

### 1.1 드라이브 상태값

EZISERVO2_AXISSTATUS 는 드라이브 상태값이 정리된 구조체이며 헤더파일 (MOTION_EziSERVO2_DEFINE.h)에서 확인하실 수 있습니다.

## 2. Servo ON 제어
------------------

``` c++
if (FAS_ServoEnable(nBdID, TRUE) != FMM_OK)
{
	printf("Function(FAS_ServoEnable) was failed.\n");
	return false;
}
```

FAS_ServoEnable() 함수를 사용하여 드라이브의 Servo Enable 신호를 설정할 수 있습니다.

## 3. PUSH 모드 제어
-------------------

``` c++
DWORD dwStartSpd, dwMoveSpd;
WORD wAccel, wDecel;
int lPosition;

DWORD dwPushSpd;
WORD wPushRate;
WORD wPushMode;
int lEndPosition;

// normal position motion
dwStartSpd = 1;
dwMoveSpd = 50000;
wAccel = 500;
wDecel = 500;
lPosition = 200500;

// push motion
dwPushSpd = 2000;
wPushRate = 50;
wPushMode = 100;	// Non-stop Mode Push & 100 pulse draw-back
lEndPosition = lPosition + 10000;

if (FAS_MovePush(nBdID, dwStartSpd, dwMoveSpd, lPosition, wAccel, wDecel, wPushRate, dwPushSpd, lEndPosition, wPushMode) != FMM_OK)
{
	printf("Function(FAS_MovePush) was failed.\n");
	return false;
}
```

FAS_MovePush() 함수를 사용하여 특정 위치에서 지정된 힘을 유지하며 이동할 수 있다.

더하여 PUSH MODE 운전은 힘을 가하기 이전 움직임에 대한 설정 [시작속도, 최대속도, 가감속 시간, 절대 위치]을 할 수 있으며, 힘을 가하는 운전에 대한 설정 [PUSH 힘 비율, Push 운전 속도, PUSH 운전 절대 위치, PUSH 운전 모드]또한 할 수 있습니다.

## 4. 현재 위치값 얻기
---------------------

``` c++
int lActPos = 0;

if (FAS_GetActualPos(nBdID, &lActualPos) != FMM_OK)
{
	printf("Function(FAS_GetActualPos) was failed.\n");
	return false;
}
```

FAS_GetActualPos() 함수를 사용하여 현재 모터의 절대위치값을 파악할 수 있습니다.

## 5. IO 출력 상태 확인.
-----------------------

``` c++
DWORD dwOutput = 0;
EZISERVO2_OUTLOGIC outLogic;

if (FAS_GetIOOutput(nBdID, &dwOutput) != FMM_OK)
{
	printf("Function(FAS_GetIOOutput) was failed.\n");
	return false;
}

outlogic.dwValue = dwOutput;

printf("Position %d : %s \n", lActPos, outlogic.BIT_RESERVED0 == true ? "Work Detected!" : "Work Not Detected");```
```

FAS_GetIOOutput() 함수를 통하여 IO 출력핀의 상태를 확인 할 수 있습니다. 더하여 EZISERVO2_OUTLOGIC는 IO 출력 상태 의미를 정리한 구조체이며, PUSH 운전에서 장애물 감지시 BIT_RESERVED0 신호를 출력하게 됩니다.

### 5.1 출력 핀 상태 로직

EZISERVO2_OUTLOGIC는 헤더파일(MOTION_EziSERVO2_DEFINE.h)에서 확인하실 수 있습니다.

## 6. 감시 시간 설정
--------------------

``` c++
int lActPos = 0;
DWORD dwOutput = 0;
EZISERVO2_OUTLOGIC outLogic;
DWORD dwEndTime;
// Check the Axis status while 10 Seconds.
dwEndTime = GetTickCount() + 10 * 1000;

do
{
	Sleep(1);

	if (FAS_GetActualPos(nBdID, &lActPos) != FMM_OK)
	{
		printf("Function(FAS_GetActualPos) was failed.\n");
		return false;
	}

	if (FAS_GetIOOutput(nBdID, &dwOutput) != FMM_OK)
	{
		printf("Function(FAS_GetIOOutput) was failed.\n");
		return false;
	}

	outlogic.dwValue = dwOutput;

	printf("Position %d : %s \n", lActPos, outlogic.BIT_RESERVED0 == true ? "Work Detected!" : "Work Not Detected");

} while (GetTickCount() < dwEndTime);
```

GetTickCount() 함수는 시스템이 시작한 시점부터 소요된 시간을 측정하며 이를 응용하여 모터의 상태를 감시하는 시간을 설정할 수 있다.

## 7. 모터 정지
--------------

``` c++
if (FAS_MoveStop(nBdID) != FMM_OK)
{
	printf("Function(FAS_MoveStop) was failed.\n");
}
```

FAS_MoveStop() 함수를 사용하여 동작중인 모터를 정지 할 수 있습니다.

## 8. 드라이브 상태 감시
-----------------------

``` c++
EZISERVO2_AXISSTATUS AxisStatus;

// Check the Axis status until motor stops and the FFLAG_MOTIONING value is released.
do
{
	Sleep(1);

	if (FAS_GetAxisStatus(nBdID, &(AxisStatus.dwValue)) != FMM_OK)
	{
		printf("Function(FAS_GetAxisStatus) was failed.\n");
		return false;
	}
} while (AxisStatus.FFLAG_MOTIONING);
```

드라이브의 운전 상태값을 나타내는 FAS_GetAxisStatus() 함수를 사용하여 사용자가 원하는 특정상태 값이 확인 될 때까지 대기할 수 있습니다.

더하여 PUSH 모드 동작 완료 상태는 FFLAG_MOTIONING ('0')값으로 확인 할 수 있습니다.

## 9. 예제 프로그램 시나리오 설명
--------------------------------

해당 예제프로그램의 시나리오는 아래와 같습니다.

1. 장치 연결.
2. 드라이브 에러 체크.
3. 드라이브 Servo ON.
4. Push Mode(Non-Stop Mode) 운전 실시.
5. Push Mode 운전 진행 관련 장애물 접촉 감시(10초).
6. Push Mode 운전 정지.
7. 복귀 운전 실시.
8. 연결 해제.

## 10. 기타
----------

1. 장치 연결 및 해제에 대한 함수 설명은 [01.ConnectionExam] 프로젝트 문서를 참고하시기 바랍니다.

2. 상대 위치 이동 운전에 대한 함수 설명은 [07.MoveAbsIncPosExam] 프로젝트 문서를 참고하시기 바랍니다.
