﻿#include <iostream>
#include <unistd.h>
#include "../Include/FAS_EziMOTIONPlusE.h"

using namespace PE;

#define TCP 0
#define UDP 1

bool Connect(int nCommType, int nBdID);
bool LatchCount(int nBdID);
bool WaitSeconds(int nSecond);

int main()
{
	int nBdID = 0;

	// Device Connect
	if (Connect(TCP, nBdID) == false)
	{
		getchar();
		exit(1);
	}

	// get input pin latch signal, get a specific pin latch count, get all pin latch count, clear latch
	if (LatchCount(nBdID) != false)
	{
		getchar();
		exit(1);
	}

	// Connection Close
	FAS_Close(nBdID);

	getchar();
}

bool Connect(int nCommType, int nBdID)
{
	unsigned char byIP[4] = { 192, 168, 0, 2 }; // IP : 192.168.0.2
	bool bSuccess = true;

	// Connection
	switch (nCommType)
	{
	case TCP:
		// TCP Connection
		if (FAS_ConnectTCP(byIP[0], byIP[1], byIP[2], byIP[3], nBdID) == 0)
		{
			printf("TCP Connection Fail! \n");
			bSuccess = false;
		}
		break;

	case UDP:
		// UDP Connection
		if (FAS_Connect(byIP[0], byIP[1], byIP[2], byIP[3], nBdID) == 0)
		{
			printf("UDP Connection Fail! \n");
			bSuccess = false;
		}
		break;

	default:
		printf("Wrong communication type. \n");
		bSuccess = false;

		break;
	}

	if (bSuccess)
		printf("Connected successfully. \n");

	return bSuccess;
}

bool LatchCount(int nBdID)
{
	unsigned int uInput = 0;
	unsigned int uLatch = 0;

	unsigned char cInputNo = 0;	// Pin 0
	unsigned int nLatchCount = 0;

	unsigned int cntLatchAll[16] = { 0 };
	unsigned int uLatchMask;

	printf("Monitor a specific pin Input latch signal while 1 min... \n");

	// Monitor the specific pin input result value.
	do
	{
		// Latch status
		if (FAS_GetInput(nBdID, &uInput, &uLatch) != FMM_OK)
		{
			printf("Function(FAS_GetInput) was failed.\n");
			return false;
		}

		// Latch count
		if (FAS_GetLatchCount(nBdID, cInputNo, &nLatchCount) != FMM_OK)
		{
			printf("Function(FAS_GetLatchCount) was failed.\n");
			return false;
		}

		printf("Pin %d is %s and %s (latch count %d) \n", cInputNo, ((uInput & (0x01 << cInputNo)) ? "ON" : "OFF"), ((uLatch & (0x01 << cInputNo)) ? "latched" : "not latched"), nLatchCount);
	}
	while (WaitSeconds(60));

	// Clear the specific pin's Latch status
	uLatchMask = (0x01 << cInputNo);
	if (FAS_ClearLatch(nBdID, uLatchMask) != FMM_OK)
	{
		printf("Function(FAS_ClearLatch) was failed.\n");
		return false;
	}
	else
	{
		printf("FAS_ClearLatch Success! \n");
	}

	// Get Latch status again
	if (FAS_GetInput(nBdID, &uInput, &uLatch) != FMM_OK)
	{
		printf("Function(FAS_GetInput) was failed.\n");
		return false;
	}

	printf("Pin %d is %s \n", cInputNo, ((uLatch & (0x01 << cInputNo)) ? "latched" : "not latched"));

	// Get latch counts of all inputs (16 inputs)
	if (FAS_GetLatchCountAll(nBdID, (unsigned int**)cntLatchAll) != FMM_OK)
	{
		printf("Function(FAS_GetLatchCountAll) was failed.\n");
		return false;
	}
	else
	{
		for (int i = 0; i < 16; i++)
		{
			printf("[FAS_GetLatchCountAll]  Pin[%d] : [%d]count \n", i, cntLatchAll[i]);
		}
	}

	// Clear the latch count of the specific pin
	if (FAS_ClearLatchCount(nBdID, uLatchMask) != FMM_OK)
	{
		printf("Function(FAS_ClearLatchCount) was failed.\n");
		return false;
	}
	else
	{
		printf("FAS_ClearLatchCount Success! \n");
	}

	return true;
}

bool WaitSeconds(int nSecond)
{
	usleep(100 * 1000);

	static int nCnt = 0;
	if (nCnt++ < nSecond * 10)
		return true;
	else
		return false;
}

