LatchExam 예제
==============

## 1. Latch Count 읽기
---------------------

``` c++
unsigned int uInput = 0;
unsigned int uLatch = 0;

unsigned char cInputNo = 0;	// Pin 0
unsigned int nLatchCount = 0;

// Monitor the specific pin input result value.
do
{
	// Latch status
	if (FAS_GetInput(nBdID, &uInput, &uLatch) != FMM_OK)
	{
		printf("Function(FAS_GetInput) was failed.\n");
		return false;
	}

	// Latch count
	if (FAS_GetLatchCount(nBdID, cInputNo, &nLatchCount) != FMM_OK)
	{
		printf("Function(FAS_GetLatchCount) was failed.\n");
		return false;
	}

	printf("Pin %d is %s and %s (latch count %d) \n", cInputNo, ((uInput & (0x01 << cInputNo)) ? "ON" : "OFF"), ((uLatch & (0x01 << cInputNo)) ? "latched" : "not latched"), nLatchCount);
} while (WaitSeconds(60));
```

FAS_GetLatchCount() 함수를 사용하여 특정 핀의 Latch Count를 읽을 수 있습니다.
위 소스 코드는 60초간 'Input / Latch 상태 읽기'와 'Latch Count 읽기'를 반복합니다.

### 1.1 Input / Latch 상태 읽기

FAS_GetInput() 함수를 사용하여 Input bit와 Latch에 대한 정보를 읽을 수 있습니다.
자세한 내용은 [15.GetInputExam] 프로젝트 문서를 참고하시기 바랍니다.

## 2. Latch 상태 초기화
---------------------

``` c++
// Clear the specific pin's Latch status
uLatchMask = (0x01 << cInputNo);
if (FAS_ClearLatch(nBdID, uLatchMask) != FMM_OK)
{
	printf("Function(FAS_ClearLatch) was failed.\n");
	return false;
}
```

FAS_ClearLatch() 함수를 사용하여 Latch 상태를 초기화 할 수 있습니다.

### 2.1 송신 데이터의 구조

uLatchMask(32bit)의 LSB에 0번 Latch 상태에 대한 요청부터 MSB에 31번 Latch 상태에 대한 요청이 순차적으로 쓰여집니다.
각 bit의 값이 0인 경우 현재 상태 유지, 1인 경우 Latch를 Clear합니다.

## 3. 전체 Latch Count 읽기 (16 Input)
------------------------------------

``` c++
unsigned int cntLatchAll[16] = { 0 };

// Get latch counts of all inputs (16 Inputs)
if (FAS_GetLatchCountAll(nBdID, (unsigned int**)cntLatchAll) != FMM_OK)
{
	printf("Function(FAS_GetLatchCountAll) was failed.\n");
	return false;
}
else
{
	for (int i = 0; i < 16; i++)
	{
		printf("[FAS_GetLatchCountAll]  Pin[%d] : [%d]count \n", i, cntLatchAll[i]);
	}
}
```

FAS_GetLatchCountAll() 함수를 사용하여 16 Input에 대해 전체 Latch Count를 읽습니다.
32 Input에 대한 요청은 FAS_GetLatchCountAll32()를 사용합니다.

## 4. Latch Count 초기화
----------------------

``` c++
unsigned int uLatchMask;
uLatchMask = (0x01 << cInputNo);

// Clear the latch count of the specific pin
if (FAS_ClearLatchCount(nBdID, uLatchMask) != FMM_OK)
{
	printf("Function(FAS_ClearLatchCount) was failed.\n");
	return false;
}
```

FAS_ClearLatchCount() 함수를 통하여 특정 bit의 Latch Count를 초기화 합니다.

## 5. 예제 프로그램 시나리오 설명
----------------------------

해당 예제프로그램의 시나리오는 아래와 같습니다.

1. 장치 연결.
2. 60초간 Input / Latch 상태 읽기, 0번 Pin의 Latch Count 읽기.
3. 0번 Pin의 Latch 상태 초기화.
4. Input / Latch 상태 읽기.
5. 전체 Latch Count 읽기.
6. 0번 Pin의 Latch Count 초기화.
7. 연결 해제.

## 6. 기타
---------

1. 장치 연결 및 해제에 대한 함수 설명은 [01.ConnectionExam] 프로젝트 문서를 참고하시기 바랍니다.
