﻿#include <iostream>
#include "../Include/FAS_EziMOTIONPlusE.h"

using namespace PE;

#define TCP 0
#define UDP 1

#define OUTPUTPIN   16

bool Connect(int nCommType, int nBdID);
bool SetOutput(int nBdID);

int main()
{
	int nBdID = 0;

	// Device Connect
	if (Connect(TCP, nBdID) == false)
	{
		getchar();
		exit(1);
	}

	// Set Output Status
	if (SetOutput(nBdID) == false)
	{
		getchar();
		exit(1);
	}

	//Connection Close
	FAS_Close(nBdID);

	getchar();
}

bool Connect(int nCommType, int nBdID)
{
	unsigned char byIP[4] = { 192, 168, 0, 2 }; // IP : 192.168.0.2
	bool bSuccess = true;

	// Connection
	switch (nCommType)
	{
	case TCP:
		// TCP Connection
		if (FAS_ConnectTCP(byIP[0], byIP[1], byIP[2], byIP[3], nBdID) == false)
		{
			printf("TCP Connection Fail! \n");
			bSuccess = false;
		}
		break;

	case UDP:
		// UDP Connection
		if (FAS_Connect(byIP[0], byIP[1], byIP[2], byIP[3], nBdID) == false)
		{
			printf("UDP Connection Fail! \n");
			bSuccess = false;
		}
		break;

	default:
		printf("Wrong communication type. \n");
		bSuccess = false;

		break;
	}

	if (bSuccess)
		printf("Connected successfully. \n");

	return bSuccess;
}

bool SetOutput(int nBdID)
{
	unsigned int uOutput = 0;
	unsigned int uStatus = 0;

	unsigned int uSetMask;
	unsigned int uClrMask;
	bool bON;

	// Fastech의 Input/Output 단일 제품 (Ezi-IO-I16, Ezi-IO-O16, Ezi-IO-I32, Ezi-IO-O32 등)은 Input과 Output의 BitMask가 각각 0x01부터 시작하지만, 
	// Input+Output 혼합 제품 (Ezi-IO-I8O8, Ezi-IO-I16O16 등)은 Input의 BitMask를 전부 할당한 뒤, Output의 BitMask가 이어서 할당되어있습니다.
	// 예를들어 Ezi-IO-I8O8의 Input 0번의 BitMask는 0x0001, Output 0번의 BitMask는 0x0100입니다. 
	// 자세한 할당 방식은 해당 예제의 doc.md파일 1.3절을 참고 부탁드립니다.

	printf("----------------------------------------- \n");
	printf("Clearing All outputs (bit 0 ~ bit 15.)\n");
	uSetMask = 0x00;
	uClrMask = 0xFFFF;
	if (FAS_SetOutput(nBdID, uSetMask, uClrMask) != FMM_OK)
	{
		printf("Function(FAS_SetOutput) was failed.\n");
	}
	else
	{
		printf("FAS_SetOutput Success! \n");
	}

	// Check OutputPin Status
	if (FAS_GetOutput(nBdID, &uOutput, &uStatus) != FMM_OK)
	{
		printf("Function(FAS_GetOutput) was failed.\n");
	}
	else
	{
		for (int i = 0; i < OUTPUTPIN; i++)
		{
			bON = ((uOutput & (0x01 << i)) != 0);
			printf("OutPin[%d] = %s \n", i, ((bON) ? "ON" : "OFF"));
		}
	}

	printf("----------------------------------------- \n");
	printf("Set output bit #0.\n");
	uSetMask = 0x01;
	uClrMask = 0x00;
	if (FAS_SetOutput(nBdID, uSetMask, uClrMask) != FMM_OK)
	{
		printf("Function(FAS_SetOutput) was failed.\n");
	}
	else
	{
		printf("FAS_SetOutput Success! \n");
	}

	// Check OutputPin Status
	if (FAS_GetOutput(nBdID, &uOutput, &uStatus) != FMM_OK)
	{
		printf("Function(FAS_GetOutput) was failed.\n");
	}
	else
	{
		for (int i = 0; i < OUTPUTPIN; i++)
		{
			bON = ((uOutput & (0x01 << i)) != 0);
			printf("OutPin[%d] = %s \n", i, ((bON) ? "ON" : "OFF"));
		}
	}

	printf("----------------------------------------- \n");
	printf("Clear bit #0 and Set bit #3, #4, #5.\n");
	uSetMask = 0x08 | 0x10 | 0x20;
	uClrMask = 0x01;
	if (FAS_SetOutput(nBdID, uSetMask, uClrMask) != FMM_OK)
	{
		printf("Function(FAS_SetOutput) was failed.\n");
	}
	else
	{
		printf("FAS_SetOutput Success! \n");
	}

	// Check OutputPin Status
	if (FAS_GetOutput(nBdID, &uOutput, &uStatus) != FMM_OK)
	{
		printf("Function(FAS_GetOutput) was failed.\n");
	}
	else
	{
		for (int i = 0; i < OUTPUTPIN; i++)
		{
			bON = ((uOutput & (0x01 << i)) != 0);
			printf("OutPin[%d] = %s \n", i, ((bON) ? "ON" : "OFF"));
		}
	}

	return true;
}
