﻿#include <iostream>
#include <unistd.h>
#include "../Include/FAS_EziMOTIONPlusE.h"

using namespace PE;

#define TCP 0
#define UDP 1

bool Connect(int nCommType, int nBdID);
bool SetTrigger(int nBdID);

int main()
{
	int nBdID = 0;

	// Device Connect
	if (Connect(TCP, nBdID) == false)
	{
		getchar();
		exit(1);
	}

	// Trigger Set and Check Count
	if (SetTrigger(nBdID) == false)
	{
		getchar();
		exit(1);
	}

	//Connection Close
	FAS_Close(nBdID);

	getchar();
}

bool Connect(int nCommType, int nBdID)
{
	unsigned char byIP[4] = { 192, 168, 0, 2 }; // IP : 192.168.0.2
	bool bSuccess = true;

	// Connection
	switch (nCommType)
	{
	case TCP:
		// TCP Connection
		if (FAS_ConnectTCP(byIP[0], byIP[1], byIP[2], byIP[3], nBdID) == false)
		{
			printf("TCP Connection Fail! \n");
			bSuccess = false;
		}
		break;

	case UDP:
		// UDP Connection
		if (FAS_Connect(byIP[0], byIP[1], byIP[2], byIP[3], nBdID) == false)
		{
			printf("UDP Connection Fail! \n");
			bSuccess = false;
		}
		break;

	default:
		printf("Wrong communication type. \n");
		bSuccess = false;

		break;
	}

	if (bSuccess)
		printf("Connected successfully. \n");

	return bSuccess;
}

bool SetTrigger(int nBdID)
{
	TRIGGER_INFO Trg_Info = { 0 };
	unsigned char cOutputNo;

	unsigned int uRunMask;
	unsigned int uStopMask;
	unsigned int uCount = 0;

	// Set Trigger value.
	cOutputNo = 0;			// Output pin #0
	Trg_Info.wCount = 20;	// Set the number of Trigger outputs
	Trg_Info.wOnTime = 250;	// On Time Setting : 250 [ms]
	Trg_Info.wPeriod = 500;	// Set Trigger period : 500 [ms]

	if (FAS_SetTrigger(nBdID, cOutputNo, &Trg_Info) != FMM_OK)
	{
		printf("Function(FAS_SetTrigger) was failed.\n");
		return false;
	}
	else
	{
		printf("FAS_SetTrigger Success! \n");
	}

	// Fastech의 Input/Output 단일 제품 (Ezi-IO-I16, Ezi-IO-O16, Ezi-IO-I32, Ezi-IO-O32 등)은 Input과 Output의 BitMask가 각각 0x01부터 시작하지만, 
	// Input+Output 혼합 제품 (Ezi-IO-I8O8, Ezi-IO-I16O16 등)은 Input의 BitMask를 전부 할당한 뒤, Output의 BitMask가 이어서 할당되어있습니다.
	// 예를들어 Ezi-IO-I8O8의 Input 0번의 BitMask는 0x0001, Output 0번의 BitMask는 0x0100입니다. 
	// 자세한 할당 방식은 17.SetOutputExam예제의 doc.md파일 1.3절을 참고 부탁드립니다.

	// Run Output
	uRunMask = (0x01 << cOutputNo); // Run Output Pin #0
	uStopMask = 0x00000000;
	if (FAS_SetRunStop(nBdID, uRunMask, uStopMask) != FMM_OK)
	{
		printf("Function(FAS_SetRunStop) was failed.\n");
		return false;
	}
	else
	{
		printf("FAS_SetRunStop Success! \n");
	}

	do
	{
		usleep(100 * 1000);

		if (FAS_GetTriggerCount(nBdID, cOutputNo, &uCount) != FMM_OK)
		{
			printf("Function(FAS_GetTriggerCount) was failed.\n");
			return false;
		}
		else
		{
			printf("Get Trigger [%d] count \n", uCount);
		}
	}
	while (uCount < Trg_Info.wCount);

	return true;
}
