TriggerExam 예제
================

## 1. Trigger 설정
-----------------

``` c++
TRIGGER_INFO Trg_Info = {0};
unsigned char cOutputNo;

// Set Trigger value.
cOutputNo = 0;			// Output pin #0
Trg_Info.wCount = 20;	// Set the number of Trigger outputs
Trg_Info.wOnTime = 250;	// On Time Setting : 250 [ms]
Trg_Info.wPeriod = 500;	// Set Trigger period : 500 [ms]

if (FAS_SetTrigger(nBdID, cOutputNo, &Trg_Info) != FMM_OK)
{
	printf("Function(FAS_SetTrigger) was failed.\n");
	return false;
}
```

FAS_SetTrigger() 함수를 사용하여 Trigger에 대한 설정을 할 수 있습니다.

### 1.1 TRIGGER_INFO 구조체에 대한 정보

TRIGGER_INFO는 Trigger 설정에 대한 정보를 담은 구조체입니다.

TRIGGER_INFO의 각 멤버 변수는 다음을 의미합니다.
wCount는 Trigger 출력 횟수
wOnTime은 Trigger On 시간 설정
wPeriod은 Trigger On 주기
위 소스 코드는 500ms 주기로 250ms동안 20회 Trigger가 On이 됩니다.

TRIGGER_INFO는 MOTION_DEFINE.h에 선언되어 있습니다.

## 2. Trigger 시작
-----------------

``` c++
unsigned int uRunMask;
unsigned int uStopMask;

// Run Output
uRunMask = (0x01 << cOutputNo); // Run Output Pin #0
uStopMask = 0x00000000;
if (FAS_SetRunStop(nBdID, uRunMask, uStopMask) != FMM_OK)
{
	printf("Function(FAS_SetRunStop) was failed.\n");
	return false;
}
```

FAS_SetRunStop() 함수를 사용하여 Trigger를 Run/Stop 시킬 수 있습니다.
uRunMask의 LSB에 0번 Trigger Run 요청부터 MSB에 31번 Trigger Run 요청이 순차적으로 쓰여집니다.
uStopMask의 LSB에 0번 Trigger Stop 요청부터 MSB에 31번 Trigger Stop 요청이 순차적으로 쓰여집니다.

## 3. Trigger 횟수 감지
---------------------

``` c++
unsigned char cOutputNo = 0;			// Output pin #0
unsigned int uCount = 0;

do
{
	Sleep(100);

	if (FAS_GetTriggerCount(nBdID, cOutputNo, &uCount) != FMM_OK)
	{
		printf("Function(FAS_GetTriggerCount) was failed.\n");
		return false;
	}
	else
	{
		printf("Get Trigger [%d] count \n", uCount);
	}
} while (uCount < Trg_Info.wCount);
```

FAS_GetTriggerCount() 함수를 통하여 특정 Output Pin의 Trigger 발생 횟수를 읽어올 수 있습니다.

## 4. 예제 프로그램 시나리오 설명
-----------------------------

해당 예제프로그램의 시나리오는 아래와 같습니다.

1. 장치 연결.
2. Trigger 설정.
3. Trigger 시작.
4. Trigget 횟수 감지.
5. 연결 해제.

## 5. 기타
---------

1. 장치 연결 및 해제에 대한 함수 설명은 [01.ConnectionExam] 프로젝트 문서를 참고하시기 바랍니다.
