﻿#include <iostream>
#include "../Include/FAS_EziMOTIONPlusE.h"

using namespace PE;

#define TCP 0
#define UDP 1

bool Connect(int nCommType, int nBdID);
bool GetIOLevel(int nBdID);
bool SetIOLevel(int nBdID);

int main()
{
	int nBdID = 0;

	// Device Connect
	if (Connect(TCP, nBdID) == false)
	{
		getchar();
		exit(1);
	}

	// Get IO Level
	if (GetIOLevel(nBdID) == false)
	{
		getchar();
		exit(1);
	}

	// Set IO Level
	if (SetIOLevel(nBdID) == false)
	{
		getchar();
		exit(1);
	}

	//Connection Close
	FAS_Close(nBdID);

	getchar();
}

bool Connect(int nCommType, int nBdID)
{
	unsigned char byIP[4] = { 192, 168, 0, 2 }; // IP : 192.168.0.2
	bool bSuccess = true;

	// Connection
	switch (nCommType)
	{
	case TCP:
		// TCP Connection
		if (FAS_ConnectTCP(byIP[0], byIP[1], byIP[2], byIP[3], nBdID) == false)
		{
			printf("TCP Connection Fail! \n");
			bSuccess = false;
		}
		break;

	case UDP:
		// UDP Connection
		if (FAS_Connect(byIP[0], byIP[1], byIP[2], byIP[3], nBdID) == false)
		{
			printf("UDP Connection Fail! \n");
			bSuccess = false;
		}
		break;

	default:
		printf("Wrong communication type. \n");
		bSuccess = false;

		break;
	}

	if (bSuccess)
		printf("Connected successfully. \n");

	return bSuccess;
}

bool GetIOLevel(int nBdID)
{
	unsigned int uIOLevel = 0;
	bool bLevel;

	printf("---------------------------------- \n");
	// [Before] Check IO Level Status
	if (FAS_GetIOLevel(nBdID, &uIOLevel) != FMM_OK)
	{
		printf("Function(FAS_GetIOLevel) was failed.\n");
		return false;
	}
	printf("Load IO Level Status : 0x%08x \n", uIOLevel);

	for (int i = 0; i < 16; i++)
	{
		bLevel = ((uIOLevel & (0x01 << i)) != 0);
		printf("I/O pin %d : %s\n", i, (bLevel) ? "High Active" : "Low Active");
	}

	return true;
}

bool SetIOLevel(int nBdID)
{
	// Fastech의 Input/Output 단일 제품 (Ezi-IO-I16, Ezi-IO-O16, Ezi-IO-I32, Ezi-IO-O32 등)은 Input과 Output의 BitMask가 각각 0x01부터 시작하지만, 
	// Input+Output 혼합 제품 (Ezi-IO-I8O8, Ezi-IO-I16O16 등)은 Input의 BitMask를 전부 할당한 뒤, Output의 BitMask가 이어서 할당되어있습니다.
	// 예를들어 Ezi-IO-I8O8의 Input 0번의 BitMask는 0x0001, Output 0번의 BitMask는 0x0100입니다. 
	// 자세한 할당 방식은 17.SetOutputExam예제의 doc.md파일 1.3절을 참고 부탁드립니다.

	unsigned int uIOLevel = 0x0000ff00;

	printf("---------------------------------- \n");
	// Set IO Level Status
	if (FAS_SetIOLevel(nBdID, uIOLevel) != FMM_OK)
	{
		printf("Function(FAS_SetIOLevel) was failed.\n");
	}
	else
	{
		printf("Set IO Level Status : 0x%08x \n", uIOLevel);
	}

	return true;
}
