IOLevelExam 예제
================

## 1. IO Level 정보 읽기
----------------------

``` c++
bool GetIOLevel(int nBdID)
{
	unsigned int uIOLevel = 0;
	bool bLevel;

	printf("---------------------------------- \n");
	// [Before] Check IO Level Status
	if (FAS_GetIOLevel(nBdID, &uIOLevel) != FMM_OK)
	{
		printf("Function(FAS_GetIOLevel) was failed.\n");
		return false;
	}
	printf("Load IO Level Status : 0x%08x \n", uIOLevel);

	for (int i = 0; i < 16; i++)
	{
		bLevel = ((uIOLevel & (0x01 << i)) != 0);
		printf("I/O pin %d : %s\n", i, (bLevel) ? "High Active" : "Low Active");
	}

	return true;
}
```

FAS_GetIOLevel() 함수를 사용하여 각 IO Pin에 대해 설정된 Level을 읽을 수 있습니다.
uIOLevel의 LSB에 0번 Pin의 Level부터 MSB에 31번 31번 Pin의 Level이 순차적으로 쓰여집니다.
0: Low Active Level / 1: High Active Level을 의미합니다.

## 2. IO Level 설정
------------------

``` c++
bool SetIOLevel(int nBdID)
{
	unsigned int uIOLevel = 0x0000ff00;

	printf("---------------------------------- \n");
	// Set IO Level Status
	if (FAS_SetIOLevel(nBdID, uIOLevel) != FMM_OK)
	{
		printf("Function(FAS_SetIOLevel) was failed.\n");
	}
	else
	{
		printf("Set IO Level Status : 0x%08x \n", uIOLevel);
	}

	return true;
}
```

FAS_SetIOLevel() 함수를 사용하여 각 IO Pin에 대해 Level을 설정할 수 있습니다.
uIOLevel의 LSB에 0번 Pin의 Level부터 MSB에 31번 31번 Pin의 Level을 순차적으로 입력합니다.
0: Low Active Level / 1: High Active Level을 의미합니다.
위 소스 코드는 0~7번 Pin을 Low Active Level로, 8~15번 Pin을 High Active Level로 설정합니다. (16 Pin)

## 3. 예제 프로그램 시나리오 설명
-----------------------------

해당 예제프로그램의 시나리오는 아래와 같습니다.

1. 장치 연결.
2. IO Level 정보 읽기.
3. IO Level 설정.
4. 연결 해제.

## 4. 기타
---------

1. 장치 연결 및 해제에 대한 함수 설명은 [01.ConnectionExam] 프로젝트 문서를 참고하시기 바랍니다.
