#include <iostream>
#include "../Include/FAS_EziMOTIONPlusE.h"

using namespace PE;

#define TCP 0
#define UDP 1

bool Connect(int nCommType, int nBdID);
bool SetADConfig(int nBdID);
bool GetADConfig(int nBdID);

int main()
{
	int nBdID = 0;

	// Device Connect
	if (Connect(TCP, nBdID) == false)
	{
		getchar();
		exit(1);
	}

	// Set AD Config
	if (SetADConfig(nBdID) == false)
	{
		getchar();
		exit(1);
	}

	// Get AD Config
	if (GetADConfig(nBdID) == false)
	{
		getchar();
		exit(1);
	}

	//Connection Close
	FAS_Close(nBdID);

	getchar();
}

bool Connect(int nCommType, int nBdID)
{
	unsigned char byIP[4] = { 192, 168, 0, 2 }; // IP : 192.168.0.2
	bool bSuccess = true;

	// Connection
	switch (nCommType)
	{
	case TCP:
		// TCP Connection
		if (FAS_ConnectTCP(byIP[0], byIP[1], byIP[2], byIP[3], nBdID) == false)
		{
			printf("TCP Connection Fail! \n");
			bSuccess = false;
		}
		break;

	case UDP:
		// UDP Connection
		if (FAS_Connect(byIP[0], byIP[1], byIP[2], byIP[3], nBdID) == false)
		{
			printf("UDP Connection Fail! \n");
			bSuccess = false;
		}
		break;

	default:
		printf("Wrong communication type. \n");
		bSuccess = false;

		break;
	}

	if (bSuccess)
		printf("Connected successfully. \n");

	return bSuccess;
}

bool SetADConfig(int nBdID)
{
	unsigned char byChannel = 0;			//Channel = 0
	int lADRange = 0;			//AD Range = 0
	int lFilterLen = 1000;		//Filter Length = 1000
	int lFilterOffset = -1000;	//Filter Offset = -1000
	int lRecv = 0;

	printf("---------------------------------- \n");
	// Set AD Range to 0 (-10 ~ 10[V])
	if (FAS_SetADConfig(nBdID, byChannel, TYPE_AD_RANGE, lADRange, &lRecv) != FMM_OK)
	{
		printf("Function(FAS_SetADConfig) was failed.\n");
	}
	else
	{
		printf("Set AD Config Seuccess : AD Type%d(TYPE_AD_RANGE)\n", TYPE_AD_RANGE);
	}

	// Set Filter Length to 1000
	if (FAS_SetADConfig(nBdID, byChannel, TYPE_AD_FILTER_LENGTH, lFilterLen, &lRecv) != FMM_OK)
	{
		printf("Function(FAS_SetADConfig) was failed.\n");
	}
	else
	{
		printf("Set AD Config Seuccess : AD Type%d(TYPE_AD_FILTER_LENGTH)\n", TYPE_AD_FILTER_LENGTH);
	}

	// Set Filter Offset to -1000
	if (FAS_SetADConfig(nBdID, byChannel, TYPE_AD_FILTER_OFFSET, lFilterOffset, &lRecv) != FMM_OK)
	{
		printf("Function(FAS_SetADConfig) was failed.\n");
	}
	else
	{
		printf("Set AD Config Seuccess : AD Type%d(TYPE_AD_FILTER_OFFSET)\n", TYPE_AD_FILTER_OFFSET);
	}

	return true;
}

bool GetADConfig(int nBdID)
{
	unsigned char byChannel = 0; //Channel 0
	int lRecv = 0;

	printf("---------------------------------- \n");
	// Get AD Range
	if (FAS_GetADConfig(nBdID, byChannel, TYPE_AD_RANGE, &lRecv) != FMM_OK)
	{
		printf("Function(FAS_GetADConfig) was failed.\n");
	}
	else
	{
		printf("Get AD Config Seuccess : AD Type%d(TYPE_AD_RANGE), Value = %d\n", TYPE_AD_RANGE, lRecv);
	}

	// Get Filter Length
	if (FAS_GetADConfig(nBdID, byChannel, TYPE_AD_FILTER_LENGTH, &lRecv) != FMM_OK)
	{
		printf("Function(FAS_GetADConfig) was failed.\n");
	}
	else
	{
		printf("Get AD Config Seuccess : AD Type%d(TYPE_AD_FILTER_LENGTH), Value = %d\n", TYPE_AD_FILTER_LENGTH, lRecv);
	}

	// Get Filter Offset
	if (FAS_GetADConfig(nBdID, byChannel, TYPE_AD_FILTER_OFFSET, &lRecv) != FMM_OK)
	{
		printf("Function(FAS_GetADConfig) was failed.\n");
	}
	else
	{
		printf("Get AD Config Seuccess : AD Type%d(TYPE_AD_FILTER_OFFSET), Value = %d\n", TYPE_AD_FILTER_OFFSET, lRecv);
	}

	return true;
}
