#include <iostream>
#include "../Include/FAS_EziMOTIONPlusE.h"

using namespace PE;

#define TCP 0
#define UDP 1

bool Connect(int nCommType, int nBdID);
bool SetDACConfig(int nBdID);
bool GetDACConfig(int nBdID);

int main()
{
	int nBdID = 0;

	// Device Connect
	if (Connect(TCP, nBdID) == false)
	{
		getchar();
		exit(1);
	}

	// Set DAC Config
	if (SetDACConfig(nBdID) == false)
	{
		getchar();
		exit(1);
	}

	// Get DAC Config
	if (GetDACConfig(nBdID) == false)
	{
		getchar();
		exit(1);
	}

	//Connection Close
	FAS_Close(nBdID);

	getchar();
}

bool Connect(int nCommType, int nBdID)
{
	unsigned char byIP[4] = { 192, 168, 0, 2 }; // IP : 192.168.0.2
	bool bSuccess = true;

	// Connection
	switch (nCommType)
	{
	case TCP:
		// TCP Connection
		if (FAS_ConnectTCP(byIP[0], byIP[1], byIP[2], byIP[3], nBdID) == false)
		{
			printf("TCP Connection Fail! \n");
			bSuccess = false;
		}
		break;

	case UDP:
		// UDP Connection
		if (FAS_Connect(byIP[0], byIP[1], byIP[2], byIP[3], nBdID) == false)
		{
			printf("UDP Connection Fail! \n");
			bSuccess = false;
		}
		break;

	default:
		printf("Wrong communication type. \n");
		bSuccess = false;

		break;
	}

	if (bSuccess)
		printf("Connected successfully. \n");

	return bSuccess;
}

bool SetDACConfig(int nBdID)
{
	unsigned char byChannel = 0;				//Channel = 0
	int lDACRange = 0;				//AD Range = 0
	int lCalbrationHigh = 24000;	//Calibration High = 24000
	int lCalbrationLow = -1000;	//Calibration Low = -1000
	int lRecv = 0;

	printf("---------------------------------- \n");
	// Set DAC Range to 0 (0 ~ 5[V])
	if (FAS_SetDACConfig(nBdID, byChannel, DAC_RANGE, lDACRange, &lRecv) != FMM_OK)
	{
		printf("Function(FAS_SetDACConfig) was failed.\n");
	}
	else
	{
		printf("Set DAC Config Seuccess : DAC Type%d(TYPE_AD_RANGE)\n", DAC_RANGE);
	}

	// Set DAC Calibration High to 24000
	if (FAS_SetDACConfig(nBdID, byChannel, DAC_CALIBRATION_HIGH, lCalbrationHigh, &lRecv) != FMM_OK)
	{
		printf("Function(FAS_SetDACConfig) was failed.\n");
	}
	else
	{
		printf("Set DAC Config Seuccess : DAC Type%d(DAC_CALIBRATION_HIGH)\n", DAC_CALIBRATION_HIGH);
	}

	// Set DAC Calibration Low to -1000
	if (FAS_SetDACConfig(nBdID, byChannel, DAC_CALIBRATION_LOW, lCalbrationLow, &lRecv) != FMM_OK)
	{
		printf("Function(FAS_SetDACConfig) was failed.\n");
	}
	else
	{
		printf("Set DAC Config Seuccess : DAC Type%d(DAC_CALIBRATION_LOW)\n", DAC_CALIBRATION_LOW);
	}

	return true;
}

bool GetDACConfig(int nBdID)
{
	unsigned char byChannel = 0;	//Channel 0
	int lRecv = 0;

	printf("---------------------------------- \n");
	// Get DAC Range
	if (FAS_GetDACConfig(nBdID, byChannel, DAC_RANGE, &lRecv) != FMM_OK)
	{
		printf("Function(FAS_GetDACConfig) was failed.\n");
	}
	else
	{
		printf("Get DAC Config Seuccess : DAC Type%d(TYPE_AD_RANGE), Value = %d\n", DAC_RANGE, lRecv);
	}

	// Get DAC Calibration High
	if (FAS_GetDACConfig(nBdID, byChannel, DAC_CALIBRATION_HIGH, &lRecv) != FMM_OK)
	{
		printf("Function(FAS_GetDACConfig) was failed.\n");
	}
	else
	{
		printf("Get DAC Config Seuccess : DAC Type%d(DAC_CALIBRATION_HIGH), Value = %d\n", DAC_CALIBRATION_HIGH, lRecv);
	}

	// Get DAC Calibration Low
	if (FAS_GetDACConfig(nBdID, byChannel, DAC_CALIBRATION_LOW, &lRecv) != FMM_OK)
	{
		printf("Function(FAS_GetDACConfig) was failed.\n");
	}
	else
	{
		printf("Get DAC Config Seuccess : DAC Type%d(DAC_CALIBRATION_LOW), Value = %d\n", DAC_CALIBRATION_LOW, lRecv);
	}

	return true;
}
