#include <iostream>
#include <unistd.h>
#include "../Include/FAS_EziMOTIONPlusE.h"

using namespace PE;

#define TCP 0
#define UDP 1

bool Connect(int nCommType, int nBdID, int nBdID2);
bool CheckDriveErr(int nBdID);
bool SetServoOn(int nBdID);
bool SetCounterTrigger(int nBdID, int nBdID2);

int main()
{
	//nBdID: Encoder,	nBdID2: I/O Counter
	int nBdID = 0, nBdID2 = 1;

	// Device Connect
	if (Connect(TCP, nBdID, nBdID2) == false)
	{
		getchar();
		exit(1);
	}

	// Drive Error Check
	if (CheckDriveErr(nBdID) == false)
	{
		getchar();
		exit(1);
	}

	// ServoOn 
	if (SetServoOn(nBdID) == false)
	{
		getchar();
		exit(1);
	}

	// Set Counter Trigger
	if (SetCounterTrigger(nBdID, nBdID2) == false)
	{
		getchar();
		exit(1);
	}

	//Connection Close
	FAS_Close(nBdID);
	FAS_Close(nBdID2);

	getchar();
}

bool Connect(int nCommType, int nBdID, int nBdID2)
{
	unsigned char byIP[4] = { 192, 168, 0, 2 }; // IP : 192.168.0.2,		Encoder
	unsigned char byIP2[4] = { 192, 168, 0, 3 }; // IP : 192.168.0.3,	I/O Counter
	bool bSuccess = true;

	// Connection
	switch (nCommType)
	{
	case TCP:
		// TCP Connection
		if (FAS_ConnectTCP(byIP[0], byIP[1], byIP[2], byIP[3], nBdID) == false)
		{
			printf("TCP Connection Fail! \n");
			bSuccess = false;
		}
		if (FAS_ConnectTCP(byIP2[0], byIP2[1], byIP2[2], byIP2[3], nBdID2) == false)
		{
			printf("TCP Connection Fail! \n");
			bSuccess = false;
		}
		break;

	case UDP:
		// UDP Connection
		if (FAS_Connect(byIP[0], byIP[1], byIP[2], byIP[3], nBdID) == false)
		{
			printf("UDP Connection Fail! \n");
			bSuccess = false;
		}
		if (FAS_Connect(byIP2[0], byIP2[1], byIP2[2], byIP2[3], nBdID2) == false)
		{
			printf("UDP Connection Fail! \n");
			bSuccess = false;
		}
		break;

	default:
		printf("Wrong communication type. \n");
		bSuccess = false;

		break;
	}

	if (bSuccess)
		printf("Connected successfully. \n");

	return bSuccess;
}

bool CheckDriveErr(int nBdID)
{
	// Check Drive's Error
	EZISERVO2_AXISSTATUS AxisStatus;

	if (FAS_GetAxisStatus(nBdID, &(AxisStatus.dwValue)) != FMM_OK)
	{
		printf("Function(FAS_GetAxisStatus) was failed.\n");
		return false;
	}

	if (AxisStatus.FFLAG_ERRORALL)
	{
		// if Drive's Error was detected, Reset the ServoAlarm
		if (FAS_ServoAlarmReset(nBdID) != FMM_OK)
		{
			printf("Function(FAS_ServoAlarmReset) was failed.\n");
			return false;
		}
	}

	return true;
}

bool SetServoOn(int nBdID)
{
	// Check Drive's Servo Status
	EZISERVO2_AXISSTATUS AxisStatus;

	// if ServoOnFlagBit is OFF('0'), switch to ON('1')
	if (FAS_GetAxisStatus(nBdID, &(AxisStatus.dwValue)) != FMM_OK)
	{
		printf("Function(FAS_GetAxisStatus) was failed.\n");
		return false;
	}

	if (AxisStatus.FFLAG_SERVOON == 0)
	{
		if (FAS_ServoEnable(nBdID, 1) != FMM_OK)
		{
			printf("Function(FAS_ServoEnable) was failed.\n");
			return false;
		}

		do
		{
			usleep(1000);

			if (FAS_GetAxisStatus(nBdID, &(AxisStatus.dwValue)) != FMM_OK)
			{
				printf("Function(FAS_GetAxisStatus) was failed.\n");
				return false;
			}

			if (AxisStatus.FFLAG_SERVOON)
				printf("Servo ON \n");
		}
		while (!AxisStatus.FFLAG_SERVOON); // Wait until FFLAG_SERVOON is ON
	}
	else
	{
		printf("Servo is already ON \n");
	}

	return true;
}

bool SetCounterTrigger(int nBdID, int nBdID2)
{
	unsigned char byChannel = 0;
	int bStartTrigger = 1;
	int lStartPos = 50000;
	unsigned int dwPeriod = 50000;
	unsigned int dwPulseTime = 500;
	unsigned int dwTriggerCount = 10;

	EZISERVO2_AXISSTATUS AxisStatus;
	int lIncPos;
	int lVelocity;

	//Set Counter Enable
	if (FAS_CounterCommand(nBdID2, byChannel, CNTCMD_CH_ENABLE, 1))
	{
		printf("Function(FAS_CounterCommand) was failed.\n");
		return false;
	}
	else
	{
		printf("FAS_CounterCommand Success! \n");
	}

	//Reset Counter
	if (FAS_CounterCommand(nBdID2, byChannel, CNTCMD_RESET_ALL, 0))
	{
		printf("Function(FAS_CounterCommand) was failed.\n");
		return false;
	}
	else
	{
		printf("FAS_CounterCommand Success! \n");
	}

	//Set Counter Trigger
	if (FAS_SetCounterTrigger(nBdID2, byChannel, bStartTrigger, lStartPos, dwPeriod, dwPulseTime, dwTriggerCount) != FMM_OK)
	{
		printf("Function(FAS_SetCounterTrigger) was failed.\n");
		return false;
	}
	else
	{
		printf("FAS_SetCounterTrigger Success! \n");
	}

	printf("---------------------------\n");
	// Increase the motor by 500000 pulse (target position : Relative position)

	lIncPos = 500000;
	lVelocity = 30000;

	printf("[Inc Mode] Move Motor ! \n");

	if (FAS_MoveSingleAxisIncPos(nBdID, lIncPos, lVelocity) != FMM_OK)
	{
		printf("Function(FAS_MoveSingleAxisIncPos) was failed.\n");
		return false;
	}

	// Check the Axis status until motor stops and the Inposition value is checked
	do
	{
		usleep(1000);

		if (FAS_GetAxisStatus(nBdID, &(AxisStatus.dwValue)) != FMM_OK)
		{
			printf("Function(FAS_GetAxisStatus) was failed.\n");
			return false;
		}
	}
	while (AxisStatus.FFLAG_MOTIONING || !(AxisStatus.FFLAG_INPOSITION));

	return true;
}
