SetCounterTriggerExam 예제
===================

## 1. 드라이브 에러 상태 확인
----------------------------

``` c++
// Check Drive's Error
EZISERVO2_AXISSTATUS AxisStatus;

if (FAS_GetAxisStatus(nBdID, &(AxisStatus.dwValue)) != FMM_OK)
{
	printf("Function(FAS_GetAxisStatus) was failed.\n");
	return false;
}

if (AxisStatus.FFLAG_ERRORALL)
{
	// if Drive's Error was detected, Reset the ServoAlarm
	if (FAS_ServoAlarmReset(nBdID) != FMM_OK)
	{
		printf("Function(FAS_ServoAlarmReset) was failed.\n");
		return false;
	}
}
```

FAS_GetAxisStatus() 함수를 사용하여 현재 드라이브의 운전 상태를 확인 할 수 있습니다. FAS_ServoAlarmReset() 함수를 사용하여 현재 드라이브의 알람상태를 리셋 할 수 있습니다.

### 1.1 드라이브 상태값

EZISERVO2_AXISSTATUS 는 드라이브 상태값이 정리된 구조체이며 헤더파일 (MOTION_EziSERVO2_DEFINE.h)에서 확인하실 수 있습니다.

## 2. Servo ON 제어
------------------

``` c++
if (FAS_ServoEnable(nBdID, TRUE) != FMM_OK)
{
	printf("Function(FAS_ServoEnable) was failed.\n");
	return false;
}
```

FAS_ServoEnable() 함수를 사용하여 드라이브의 Servo Enable 신호를 설정할 수 있습니다.

## 3. Counter Command 설정
--------------------

``` c++
BYTE byChannel = 0;

//Set Counter Enable
if (FAS_CounterCommand(nBdID2, byChannel, CNTCMD_CH_ENABLE, 1))
{
	printf("Function(FAS_CounterCommand) was failed.\n");
	return false;
}
else
{
	printf("FAS_CounterCommand Success! \n");
}

//Reset Counter
if (FAS_CounterCommand(nBdID2, byChannel, CNTCMD_RESET_ALL, 0))
{
	printf("Function(FAS_CounterCommand) was failed.\n");
	return false;
}
else
{
	printf("FAS_CounterCommand Success! \n");
}
```

FAS_CounterCommand() 함수를 사용하여 Counter Command를 설정할 수 있습니다.
해당 함수의 각 파라미터는 순차적으로 다음을 의미합니다.
'해당 보드의 ID번호', '채널 번호', 'Counter Command Type', '수정할 값'
해당 예제에서는 Ch1의 Counter Enable 및 Counter Value를 초기화합니다.

### 3.1 Counter Command Type

COUNTER_CMD(CNTCMD_CH_ENABLE, CNTCMD_RESET_ALL)는 Counter Command Type이 정리된 구조체이며 헤더파일 (MOTION_DEFINE.h)에서 확인하실 수 있습니다.

## 4. Counter Trigger Setting
--------------------

``` c++
BYTE byChannel = 0;
BOOL bStartTrigger = TRUE;
int lStartPos = 50000;
DWORD dwPeriod = 50000;
DWORD dwPulseTime = 500;
DWORD dwTriggerCount = 10;

//Set Counter Trigger
if (FAS_SetCounterTrigger(nBdID2, byChannel, bStartTrigger, lStartPos, dwPeriod, dwPulseTime, dwTriggerCount) != FMM_OK)
{
	printf("Function(FAS_SetCounterTrigger) was failed.\n");
	return false;
}
```

FAS_SetCounterTrigger() 함수를 사용하여 Counter Trigger를 설정할 수 있습니다.
해당 함수의 각 파라미터는 순차적으로 다음을 의미합니다.
'해당 보드의 ID번호', '채널 번호', 'Trigger Off/On 여부', 'Trigger 최초 시작 위치', 'Trigger 동작 주기', 'Trigger On Time', 'Trigger 동작 회수'

## 5. 모터 상대 위치 이동 제어
-----------------------------

``` c++
EZISERVO2_AXISSTATUS AxisStatus;
int lIncPos = 500000;
int lVelocity = 30000;

if (FAS_MoveSingleAxisIncPos(nBdID, lIncPos, lVelocity) != FMM_OK)
{
	printf("Function(FAS_MoveSingleAxisIncPos) was failed.\n");
	return false;
}

// Check the Axis status until motor stops and the Inposition value is checked
do
{
	Sleep(1);

	if (FAS_GetAxisStatus(nBdID, &(AxisStatus.dwValue)) != FMM_OK)
	{
		printf("Function(FAS_GetAxisStatus) was failed.\n");
		return false;
	}
} while (AxisStatus.FFLAG_MOTIONING || !(AxisStatus.FFLAG_INPOSITION));
```

FAS_MoveSingleAxisIncPos() 함수를 사용하여 모터의 [상대 위치, 속도]으로 동작시킬 수 있습니다.

## 6. 예제 프로그램 시나리오 설명
-----------------------------

해당 예제프로그램의 시나리오는 아래와 같습니다.

1. 장치 연결.
2. 드라이브 에러 체크.
3. 드라이브 Servo ON.
4. Count Command Setting
5. Count Trigger Setting
6. 상대 위치 이동
7. 연결 해제.

## 4. 기타
---------

1. 장치 연결 및 해제에 대한 함수 설명은 [01.ConnectionExam] 프로젝트 문서를 참고하시기 바랍니다.
